@@ -1,3 +1,4 @@
+_base_ = ['../../../../_base_/datasets/jhmdb.py']
 log_level = 'INFO'
 load_from = 'https://download.openmmlab.com/mmpose/top_down/cpm/cpm_mpii_368x368-116e62b8_20200822.pth'  # noqa: E501
 resume_from = None
@@ -125,20 +126,23 @@ data = dict(
     test_dataloader=dict(samples_per_gpu=32),
     train=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub1_train.json',
+        ann_file=f'{data_root}/annotations/Sub2_train.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
-        pipeline=train_pipeline),
+        pipeline=train_pipeline,
+        dataset_info={{_base_.dataset_info}}),
     val=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub1_test.json',
+        ann_file=f'{data_root}/annotations/Sub2_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline),
+        pipeline=val_pipeline,
+        dataset_info={{_base_.dataset_info}}),
     test=dict(
         type='TopDownJhmdbDataset',
-        ann_file=f'{data_root}/annotations/Sub1_test.json',
+        ann_file=f'{data_root}/annotations/Sub2_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline),
+        pipeline=val_pipeline,
+        dataset_info={{_base_.dataset_info}}),
 )
