@@ -1,3 +1,4 @@
+_base_ = ['../../../../_base_/datasets/jhmdb.py']
 log_level = 'INFO'
 load_from = 'https://download.openmmlab.com/mmpose/top_down/resnet/res50_mpii_256x256-418ffc88_20200812.pth'  # noqa: E501
 resume_from = None
@@ -120,17 +121,20 @@ data = dict(
         ann_file=f'{data_root}/annotations/Sub2_train.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
-        pipeline=train_pipeline),
+        pipeline=train_pipeline,
+        dataset_info={{_base_.dataset_info}}),
     val=dict(
         type='TopDownJhmdbDataset',
         ann_file=f'{data_root}/annotations/Sub2_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline),
+        pipeline=val_pipeline,
+        dataset_info={{_base_.dataset_info}}),
     test=dict(
         type='TopDownJhmdbDataset',
         ann_file=f'{data_root}/annotations/Sub2_test.json',
         img_prefix=f'{data_root}/',
         data_cfg=data_cfg,
-        pipeline=val_pipeline),
+        pipeline=val_pipeline,
+        dataset_info={{_base_.dataset_info}}),
 )
