@@ -1,11 +1,14 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os
+import os.path as osp
+import warnings
 from argparse import ArgumentParser
 
-from xtcocotools.coco import COCO
+import mmcv
 
 from mmpose.apis import (inference_bottom_up_pose_model, init_pose_model,
                          vis_pose_result)
+from mmpose.datasets import DatasetInfo
 
 
 def main():
@@ -13,12 +16,10 @@ def main():
     parser = ArgumentParser()
     parser.add_argument('pose_config', help='Config file for detection')
     parser.add_argument('pose_checkpoint', help='Checkpoint file')
-    parser.add_argument('--img-root', type=str, default='', help='Image root')
     parser.add_argument(
-        '--json-file',
+        '--img-path',
         type=str,
-        default='',
-        help='Json file containing image info.')
+        help='Path to an image file or a image folder.')
     parser.add_argument(
         '--show',
         action='store_true',
@@ -54,15 +55,32 @@ def main():
 
     assert args.show or (args.out_img_root != '')
 
-    coco = COCO(args.json_file)
+    # prepare image list
+    if osp.isfile(args.img_path):
+        image_list = [args.img_path]
+    elif osp.isdir(args.img_path):
+        image_list = [
+            osp.join(args.img_path, fn) for fn in os.listdir(args.img_path)
+            if fn.lower().endswith(('.png', '.jpg', '.jpeg', '.tiff', '.bmp'))
+        ]
+    else:
+        raise ValueError('Image path should be an image or image folder.'
+                         f'Got invalid image path: {args.img_path}')
+
     # build the pose model from a config file and a checkpoint file
     pose_model = init_pose_model(
         args.pose_config, args.pose_checkpoint, device=args.device.lower())
 
     dataset = pose_model.cfg.data['test']['type']
-    assert (dataset == 'BottomUpCocoDataset')
-
-    img_keys = list(coco.imgs.keys())
+    dataset_info = pose_model.cfg.data['test'].get('dataset_info', None)
+    if dataset_info is None:
+        warnings.warn(
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        assert (dataset == 'BottomUpCocoDataset')
+    else:
+        dataset_info = DatasetInfo(dataset_info)
 
     # optional
     return_heatmap = False
@@ -71,15 +89,14 @@ def main():
     output_layer_names = None
 
     # process each image
-    for i in range(len(img_keys)):
-        image_id = img_keys[i]
-        image = coco.loadImgs(image_id)[0]
-        image_name = os.path.join(args.img_root, image['file_name'])
+    for image_name in mmcv.track_iter_progress(image_list):
 
         # test a single image, with a list of bboxes.
         pose_results, returned_outputs = inference_bottom_up_pose_model(
             pose_model,
             image_name,
+            dataset=dataset,
+            dataset_info=dataset_info,
             pose_nms_thr=args.pose_nms_thr,
             return_heatmap=return_heatmap,
             outputs=output_layer_names)
@@ -88,7 +105,8 @@ def main():
             out_file = None
         else:
             os.makedirs(args.out_img_root, exist_ok=True)
-            out_file = os.path.join(args.out_img_root, f'vis_{i}.jpg')
+            out_file = os.path.join(args.out_img_root,
+                                    f'vis_{osp.basename(image_name)}.jpg')
 
         # show the results
         vis_pose_result(
@@ -98,6 +116,7 @@ def main():
             radius=args.radius,
             thickness=args.thickness,
             dataset=dataset,
+            dataset_info=dataset_info,
             kpt_score_thr=args.kpt_thr,
             show=args.show,
             out_file=out_file)
