@@ -1,11 +1,13 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os
+import warnings
 from argparse import ArgumentParser
 
 import cv2
 
 from mmpose.apis import (inference_top_down_pose_model, init_pose_model,
                          vis_pose_tracking_result)
+from mmpose.datasets import DatasetInfo
 
 try:
     from mmtrack.apis import inference_mot
@@ -84,6 +86,14 @@ def main():
         args.pose_config, args.pose_checkpoint, device=args.device.lower())
 
     dataset = pose_model.cfg.data['test']['type']
+    dataset_info = pose_model.cfg.data['test'].get('dataset_info', None)
+    if dataset_info is None:
+        warnings.warn(
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+    else:
+        dataset_info = DatasetInfo(dataset_info)
 
     cap = cv2.VideoCapture(args.video_path)
     assert cap.isOpened(), f'Faild to load video file {args.video_path}'
@@ -130,6 +140,7 @@ def main():
             bbox_thr=args.bbox_thr,
             format='xyxy',
             dataset=dataset,
+            dataset_info=dataset_info,
             return_heatmap=return_heatmap,
             outputs=output_layer_names)
 
@@ -141,6 +152,7 @@ def main():
             radius=args.radius,
             thickness=args.thickness,
             dataset=dataset,
+            dataset_info=dataset_info,
             kpt_score_thr=args.kpt_thr,
             show=False)
 
