@@ -1,5 +1,6 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os
+import warnings
 
 import cv2
 import mmcv
@@ -135,6 +136,8 @@ class LoadImage:
             results['image_file'] = ''
             if self.color_type == 'color' and self.channel_order == 'rgb':
                 img = cv2.cvtColor(results['img_or_path'], cv2.COLOR_BGR2RGB)
+            else:
+                img = results['img_or_path']
         else:
             raise TypeError('"img_or_path" must be a numpy array or a str or '
                             'a pathlib.Path object')
@@ -146,7 +149,8 @@ class LoadImage:
 def _inference_single_pose_model(model,
                                  img_or_path,
                                  bboxes,
-                                 dataset,
+                                 dataset='TopDownCocoDataset',
+                                 dataset_info=None,
                                  return_heatmap=False):
     """Inference human bounding boxes.
 
@@ -159,7 +163,8 @@ def _inference_single_pose_model(model,
         bboxes (list | np.ndarray): All bounding boxes (with scores),
             shaped (N, 4) or (N, 5). (left, top, width, height, [score])
             where N is number of bounding boxes.
-        dataset (str): Dataset name.
+        dataset (str): Dataset name. Deprecated.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         outputs (list[str] | tuple[str]): Names of layers whose output is
             to be returned, default: None
 
@@ -179,94 +184,97 @@ def _inference_single_pose_model(model,
 
     assert len(bboxes[0]) in [4, 5]
 
-    flip_pairs = None
-    if dataset in ('TopDownCocoDataset', 'TopDownOCHumanDataset',
-                   'AnimalMacaqueDataset'):
-        flip_pairs = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12],
-                      [13, 14], [15, 16]]
-    elif dataset == 'TopDownCocoWholeBodyDataset':
-        body = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12], [13, 14],
-                [15, 16]]
-        foot = [[17, 20], [18, 21], [19, 22]]
-
-        face = [[23, 39], [24, 38], [25, 37], [26, 36], [27, 35], [28, 34],
-                [29, 33], [30, 32], [40, 49], [41, 48], [42, 47], [43, 46],
-                [44, 45], [54, 58], [55, 57], [59, 68], [60, 67], [61, 66],
-                [62, 65], [63, 70], [64, 69], [71, 77], [72, 76], [73, 75],
-                [78, 82], [79, 81], [83, 87], [84, 86], [88, 90]]
-
-        hand = [[91, 112], [92, 113], [93, 114], [94, 115], [95, 116],
-                [96, 117], [97, 118], [98, 119], [99, 120], [100, 121],
-                [101, 122], [102, 123], [103, 124], [104, 125], [105, 126],
-                [106, 127], [107, 128], [108, 129], [109, 130], [110, 131],
-                [111, 132]]
-        flip_pairs = body + foot + face + hand
-    elif dataset == 'TopDownAicDataset':
-        flip_pairs = [[0, 3], [1, 4], [2, 5], [6, 9], [7, 10], [8, 11]]
-    elif dataset == 'TopDownMpiiDataset':
-        flip_pairs = [[0, 5], [1, 4], [2, 3], [10, 15], [11, 14], [12, 13]]
-    elif dataset == 'TopDownMpiiTrbDataset':
-        flip_pairs = [[0, 1], [2, 3], [4, 5], [6, 7],
-                      [8, 9], [10, 11], [14, 15], [16, 22], [28, 34], [17, 23],
-                      [29, 35], [18, 24], [30, 36], [19, 25], [31,
-                                                               37], [20, 26],
-                      [32, 38], [21, 27], [33, 39]]
-    elif dataset == 'TopDownH36MDataset':
-        flip_pairs = [[1, 4], [2, 5], [3, 6], [11, 14], [12, 15], [13, 16]]
-    elif dataset in ('OneHand10KDataset', 'FreiHandDataset', 'PanopticDataset',
-                     'InterHand2DDataset'):
-        flip_pairs = []
-    elif dataset in 'Face300WDataset':
-        flip_pairs = [[0, 16], [1, 15], [2, 14], [3, 13], [4, 12], [5, 11],
-                      [6, 10], [7, 9], [17, 26], [18, 25], [19, 24], [20, 23],
-                      [21, 22], [31, 35], [32, 34], [36, 45], [37,
-                                                               44], [38, 43],
-                      [39, 42], [40, 47], [41, 46], [48, 54], [49,
-                                                               53], [50, 52],
-                      [61, 63], [60, 64], [67, 65], [58, 56], [59, 55]]
-
-    elif dataset in 'FaceAFLWDataset':
-        flip_pairs = [[0, 5], [1, 4], [2, 3], [6, 11], [7, 10], [8, 9],
-                      [12, 14], [15, 17]]
-
-    elif dataset in 'FaceCOFWDataset':
-        flip_pairs = [[0, 1], [4, 6], [2, 3], [5, 7], [8, 9], [10, 11],
-                      [12, 14], [16, 17], [13, 15], [18, 19], [22, 23]]
-
-    elif dataset in 'FaceWFLWDataset':
-        flip_pairs = [[0, 32], [1, 31], [2, 30], [3, 29], [4, 28], [5, 27],
-                      [6, 26], [7, 25], [8, 24], [9, 23], [10, 22], [11, 21],
-                      [12, 20], [13, 19], [14, 18], [15, 17], [33,
-                                                               46], [34, 45],
-                      [35, 44], [36, 43], [37, 42], [38, 50], [39,
-                                                               49], [40, 48],
-                      [41, 47], [60, 72], [61, 71], [62, 70], [63,
-                                                               69], [64, 68],
-                      [65, 75], [66, 74], [67, 73], [55, 59], [56,
-                                                               58], [76, 82],
-                      [77, 81], [78, 80], [87, 83], [86, 84], [88, 92],
-                      [89, 91], [95, 93], [96, 97]]
-
-    elif dataset in 'AnimalFlyDataset':
-        flip_pairs = [[1, 2], [6, 18], [7, 19], [8, 20], [9, 21], [10, 22],
-                      [11, 23], [12, 24], [13, 25], [14, 26], [15, 27],
-                      [16, 28], [17, 29], [30, 31]]
-    elif dataset in 'AnimalHorse10Dataset':
-        flip_pairs = []
-
-    elif dataset in 'AnimalLocustDataset':
-        flip_pairs = [[5, 20], [6, 21], [7, 22], [8, 23], [9, 24], [10, 25],
-                      [11, 26], [12, 27], [13, 28], [14, 29], [15, 30],
-                      [16, 31], [17, 32], [18, 33], [19, 34]]
-
-    elif dataset in 'AnimalZebraDataset':
-        flip_pairs = [[3, 4], [5, 6]]
-
-    elif dataset in 'AnimalPoseDataset':
-        flip_pairs = [[0, 1], [2, 3], [8, 9], [10, 11], [12, 13], [14, 15],
-                      [16, 17], [18, 19]]
+    if dataset_info is not None:
+        dataset_name = dataset_info.dataset_name
+        flip_pairs = dataset_info.flip_pairs
     else:
-        raise NotImplementedError()
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        # TODO: These will be removed in the later versions.
+        if dataset in ('TopDownCocoDataset', 'TopDownOCHumanDataset',
+                       'AnimalMacaqueDataset'):
+            flip_pairs = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12],
+                          [13, 14], [15, 16]]
+        elif dataset == 'TopDownCocoWholeBodyDataset':
+            body = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12],
+                    [13, 14], [15, 16]]
+            foot = [[17, 20], [18, 21], [19, 22]]
+
+            face = [[23, 39], [24, 38], [25, 37], [26, 36], [27, 35], [28, 34],
+                    [29, 33], [30, 32], [40, 49], [41, 48], [42, 47], [43, 46],
+                    [44, 45], [54, 58], [55, 57], [59, 68], [60, 67], [61, 66],
+                    [62, 65], [63, 70], [64, 69], [71, 77], [72, 76], [73, 75],
+                    [78, 82], [79, 81], [83, 87], [84, 86], [88, 90]]
+
+            hand = [[91, 112], [92, 113], [93, 114], [94, 115], [95, 116],
+                    [96, 117], [97, 118], [98, 119], [99, 120], [100, 121],
+                    [101, 122], [102, 123], [103, 124], [104, 125], [105, 126],
+                    [106, 127], [107, 128], [108, 129], [109, 130], [110, 131],
+                    [111, 132]]
+            flip_pairs = body + foot + face + hand
+        elif dataset == 'TopDownAicDataset':
+            flip_pairs = [[0, 3], [1, 4], [2, 5], [6, 9], [7, 10], [8, 11]]
+        elif dataset == 'TopDownMpiiDataset':
+            flip_pairs = [[0, 5], [1, 4], [2, 3], [10, 15], [11, 14], [12, 13]]
+        elif dataset == 'TopDownMpiiTrbDataset':
+            flip_pairs = [[0, 1], [2, 3], [4, 5], [6, 7], [8, 9], [10, 11],
+                          [14, 15], [16, 22], [28, 34], [17, 23], [29, 35],
+                          [18, 24], [30, 36], [19, 25], [31, 37], [20, 26],
+                          [32, 38], [21, 27], [33, 39]]
+        elif dataset in ('OneHand10KDataset', 'FreiHandDataset',
+                         'PanopticDataset', 'InterHand2DDataset'):
+            flip_pairs = []
+        elif dataset in 'Face300WDataset':
+            flip_pairs = [[0, 16], [1, 15], [2, 14], [3, 13], [4, 12], [5, 11],
+                          [6, 10], [7, 9], [17, 26], [18, 25], [19, 24],
+                          [20, 23], [21, 22], [31, 35], [32, 34], [36, 45],
+                          [37, 44], [38, 43], [39, 42], [40, 47], [41, 46],
+                          [48, 54], [49, 53], [50, 52], [61, 63], [60, 64],
+                          [67, 65], [58, 56], [59, 55]]
+
+        elif dataset in 'FaceAFLWDataset':
+            flip_pairs = [[0, 5], [1, 4], [2, 3], [6, 11], [7, 10], [8, 9],
+                          [12, 14], [15, 17]]
+
+        elif dataset in 'FaceCOFWDataset':
+            flip_pairs = [[0, 1], [4, 6], [2, 3], [5, 7], [8, 9], [10, 11],
+                          [12, 14], [16, 17], [13, 15], [18, 19], [22, 23]]
+
+        elif dataset in 'FaceWFLWDataset':
+            flip_pairs = [[0, 32], [1, 31], [2, 30], [3, 29], [4, 28], [5, 27],
+                          [6, 26], [7, 25], [8, 24], [9, 23], [10, 22],
+                          [11, 21], [12, 20], [13, 19], [14, 18], [15, 17],
+                          [33, 46], [34, 45], [35, 44], [36, 43], [37, 42],
+                          [38, 50], [39, 49], [40, 48], [41, 47], [60, 72],
+                          [61, 71], [62, 70], [63, 69], [64, 68], [65, 75],
+                          [66, 74], [67, 73], [55, 59], [56, 58], [76, 82],
+                          [77, 81], [78, 80], [87, 83], [86, 84], [88, 92],
+                          [89, 91], [95, 93], [96, 97]]
+
+        elif dataset in 'AnimalFlyDataset':
+            flip_pairs = [[1, 2], [6, 18], [7, 19], [8, 20], [9, 21], [10, 22],
+                          [11, 23], [12, 24], [13, 25], [14, 26], [15, 27],
+                          [16, 28], [17, 29], [30, 31]]
+        elif dataset in 'AnimalHorse10Dataset':
+            flip_pairs = []
+
+        elif dataset in 'AnimalLocustDataset':
+            flip_pairs = [[5, 20], [6, 21], [7, 22], [8, 23], [9, 24],
+                          [10, 25], [11, 26], [12, 27], [13, 28], [14, 29],
+                          [15, 30], [16, 31], [17, 32], [18, 33], [19, 34]]
+
+        elif dataset in 'AnimalZebraDataset':
+            flip_pairs = [[3, 4], [5, 6]]
+
+        elif dataset in 'AnimalPoseDataset':
+            flip_pairs = [[0, 1], [2, 3], [8, 9], [10, 11], [12, 13], [14, 15],
+                          [16, 17], [18, 19]]
+        else:
+            raise NotImplementedError()
+        dataset_name = dataset
 
     batch_data = []
     for bbox in bboxes:
@@ -285,7 +293,7 @@ def _inference_single_pose_model(model,
             'bbox_id':
             0,  # need to be assigned if batch_size > 1
             'dataset':
-            dataset,
+            dataset_name,
             'joints_3d':
             np.zeros((cfg.data_cfg.num_joints, 3), dtype=np.float32),
             'joints_3d_visible':
@@ -328,6 +336,7 @@ def inference_top_down_pose_model(model,
                                   bbox_thr=None,
                                   format='xywh',
                                   dataset='TopDownCocoDataset',
+                                  dataset_info=None,
                                   return_heatmap=False,
                                   outputs=None):
     """Inference a single image with a list of person bounding boxes.
@@ -351,6 +360,8 @@ def inference_top_down_pose_model(model,
             'xyxy' means (left, top, right, bottom),
             'xywh' means (left, top, width, height).
         dataset (str): Dataset name, e.g. 'TopDownCocoDataset'.
+            It is deprecated. Please use dataset_info instead.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         return_heatmap (bool) : Flag to return heatmap, default: False
         outputs (list(str) | tuple(str)) : Names of layers whose outputs
             need to be returned, default: None
@@ -364,6 +375,13 @@ def inference_top_down_pose_model(model,
             Output feature maps from layers specified in `outputs`.
             Includes 'heatmap' if `return_heatmap` is True.
     """
+    if dataset_info is None:
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+
     # only two kinds of bbox format is supported.
     assert format in ['xyxy', 'xywh']
 
@@ -401,7 +419,8 @@ def inference_top_down_pose_model(model,
             model,
             img_or_path,
             bboxes_xywh,
-            dataset,
+            dataset=dataset,
+            dataset_info=dataset_info,
             return_heatmap=return_heatmap)
 
         if return_heatmap:
@@ -423,6 +442,8 @@ def inference_top_down_pose_model(model,
 
 def inference_bottom_up_pose_model(model,
                                    img_or_path,
+                                   dataset='BottomUpCocoDataset',
+                                   dataset_info=None,
                                    pose_nms_thr=0.9,
                                    return_heatmap=False,
                                    outputs=None):
@@ -436,6 +457,9 @@ def inference_bottom_up_pose_model(model,
     Args:
         model (nn.Module): The loaded pose model.
         img_or_path (str| np.ndarray): Image filename or loaded image.
+        dataset (str): Dataset name, e.g. 'BottomUpCocoDataset'.
+            It is deprecated. Please use dataset_info instead.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         pose_nms_thr (float): retain oks overlap < pose_nms_thr, default: 0.9.
         return_heatmap (bool) : Flag to return heatmap, default: False.
         outputs (list(str) | tuple(str)) : Names of layers whose outputs
@@ -462,17 +486,27 @@ def inference_bottom_up_pose_model(model,
                      ] + cfg.test_pipeline[1:]
     test_pipeline = Compose(test_pipeline)
 
+    if dataset_info is not None:
+        dataset_name = dataset_info.dataset_name
+        flip_index = dataset_info.flip_index
+    else:
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        assert (dataset == 'BottomUpCocoDataset')
+        dataset_name = dataset
+        flip_index = [0, 2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 16, 15]
+
     # prepare data
     data = {
         'img_or_path': img_or_path,
-        'dataset': 'coco',
+        'dataset': dataset_name,
         'ann_info': {
-            'image_size':
-            cfg.data_cfg['image_size'],
-            'num_joints':
-            cfg.data_cfg['num_joints'],
-            'flip_index':
-            [0, 2, 1, 4, 3, 6, 5, 8, 7, 10, 9, 12, 11, 14, 13, 16, 15],
+            'image_size': cfg.data_cfg['image_size'],
+            'num_joints': cfg.data_cfg['num_joints'],
+            'flip_index': flip_index,
         }
     }
 
@@ -523,6 +557,7 @@ def vis_pose_result(model,
                     kpt_score_thr=0.3,
                     bbox_color='green',
                     dataset='TopDownCocoDataset',
+                    dataset_info=None,
                     show=False,
                     out_file=None):
     """Visualize the detection results on the image.
@@ -539,214 +574,222 @@ def vis_pose_result(model,
         show (bool):  Whether to show the image. Default True.
         out_file (str|None): The filename of the output visualization image.
     """
-    if hasattr(model, 'module'):
-        model = model.module
+    if dataset_info is not None:
+        skeleton = dataset_info.skeleton
+        pose_kpt_color = dataset_info.pose_kpt_color
+        pose_link_color = dataset_info.pose_link_color
+    else:
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        # TODO: These will be removed in the later versions.
+        palette = np.array([[255, 128, 0], [255, 153, 51], [255, 178, 102],
+                            [230, 230, 0], [255, 153, 255], [153, 204, 255],
+                            [255, 102, 255], [255, 51, 255], [102, 178, 255],
+                            [51, 153, 255], [255, 153, 153], [255, 102, 102],
+                            [255, 51, 51], [153, 255, 153], [102, 255, 102],
+                            [51, 255, 51], [0, 255, 0], [0, 0, 255],
+                            [255, 0, 0], [255, 255, 255]])
 
-    palette = np.array([[255, 128, 0], [255, 153, 51], [255, 178, 102],
-                        [230, 230, 0], [255, 153, 255], [153, 204, 255],
-                        [255, 102, 255], [255, 51, 255], [102, 178, 255],
-                        [51, 153, 255], [255, 153, 153], [255, 102, 102],
-                        [255, 51, 51], [153, 255, 153], [102, 255, 102],
-                        [51, 255, 51], [0, 255, 0], [0, 0, 255], [255, 0, 0],
-                        [255, 255, 255]])
+        if dataset in ('TopDownCocoDataset', 'BottomUpCocoDataset',
+                       'TopDownOCHumanDataset', 'AnimalMacaqueDataset'):
+            # show the results
+            skeleton = [[15, 13], [13, 11], [16, 14], [14, 12], [11, 12],
+                        [5, 11], [6, 12], [5, 6], [5, 7], [6, 8], [7, 9],
+                        [8, 10], [1, 2], [0, 1], [0, 2], [1, 3], [2, 4],
+                        [3, 5], [4, 6]]
 
-    if dataset in ('TopDownCocoDataset', 'BottomUpCocoDataset',
-                   'TopDownOCHumanDataset', 'AnimalMacaqueDataset'):
-        # show the results
-        skeleton = [[16, 14], [14, 12], [17, 15], [15, 13], [12, 13], [6, 12],
-                    [7, 13], [6, 7], [6, 8], [7, 9], [8, 10], [9, 11], [2, 3],
-                    [1, 2], [1, 3], [2, 4], [3, 5], [4, 6], [5, 7]]
+            pose_link_color = palette[[
+                0, 0, 0, 0, 7, 7, 7, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 16
+            ]]
+            pose_kpt_color = palette[[
+                16, 16, 16, 16, 16, 9, 9, 9, 9, 9, 9, 0, 0, 0, 0, 0, 0
+            ]]
 
-        pose_limb_color = palette[[
-            0, 0, 0, 0, 7, 7, 7, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 16
-        ]]
-        pose_kpt_color = palette[[
-            16, 16, 16, 16, 16, 9, 9, 9, 9, 9, 9, 0, 0, 0, 0, 0, 0
-        ]]
+        elif dataset == 'TopDownCocoWholeBodyDataset':
+            # show the results
+            skeleton = [[15, 13], [13, 11], [16, 14], [14, 12], [11, 12],
+                        [5, 11], [6, 12], [5, 6], [5, 7], [6, 8], [7, 9],
+                        [8, 10], [1, 2], [0, 1], [0, 2],
+                        [1, 3], [2, 4], [3, 5], [4, 6], [15, 17], [15, 18],
+                        [15, 19], [16, 20], [16, 21], [16, 22], [91, 92],
+                        [92, 93], [93, 94], [94, 95], [91, 96], [96, 97],
+                        [97, 98], [98, 99], [91, 100], [100, 101], [101, 102],
+                        [102, 103], [91, 104], [104, 105], [105, 106],
+                        [106, 107], [91, 108], [108, 109], [109, 110],
+                        [110, 111], [112, 113], [113, 114], [114, 115],
+                        [115, 116], [112, 117], [117, 118], [118, 119],
+                        [119, 120], [112, 121], [121, 122], [122, 123],
+                        [123, 124], [112, 125], [125, 126], [126, 127],
+                        [127, 128], [112, 129], [129, 130], [130, 131],
+                        [131, 132]]
 
-    elif dataset == 'TopDownCocoWholeBodyDataset':
-        # show the results
-        skeleton = [[16, 14], [14, 12], [17, 15], [15, 13], [12, 13], [6, 12],
-                    [7, 13], [6, 7], [6, 8], [7, 9], [8, 10], [9, 11], [2, 3],
-                    [1, 2], [1, 3], [2, 4], [3, 5], [4, 6], [5, 7], [16, 18],
-                    [16, 19], [16, 20], [17, 21], [17, 22], [17, 23], [92, 93],
-                    [93, 94], [94, 95], [95, 96], [92, 97], [97, 98], [98, 99],
-                    [99, 100], [92, 101], [101, 102], [102, 103], [103, 104],
-                    [92, 105], [105, 106], [106, 107], [107, 108], [92, 109],
-                    [109, 110], [110, 111], [111, 112], [113, 114], [114, 115],
-                    [115, 116], [116, 117], [113, 118], [118, 119], [119, 120],
-                    [120, 121], [113, 122], [122, 123], [123, 124], [124, 125],
-                    [113, 126], [126, 127], [127, 128], [128, 129], [113, 130],
-                    [130, 131], [131, 132], [132, 133]]
-
-        pose_limb_color = palette[
-            [0, 0, 0, 0, 7, 7, 7, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 16] +
-            [16, 16, 16, 16, 16, 16] + [
+            pose_link_color = palette[[
+                0, 0, 0, 0, 7, 7, 7, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 16
+            ] + [16, 16, 16, 16, 16, 16] + [
                 0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16,
                 16
             ] + [
                 0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16,
                 16
             ]]
-        pose_kpt_color = palette[
-            [16, 16, 16, 16, 16, 9, 9, 9, 9, 9, 9, 0, 0, 0, 0, 0, 0] +
-            [0, 0, 0, 0, 0, 0] + [19] * (68 + 42)]
+            pose_kpt_color = palette[
+                [16, 16, 16, 16, 16, 9, 9, 9, 9, 9, 9, 0, 0, 0, 0, 0, 0] +
+                [0, 0, 0, 0, 0, 0] + [19] * (68 + 42)]
 
-    elif dataset == 'TopDownAicDataset':
-        skeleton = [[3, 2], [2, 1], [1, 14], [14, 4], [4, 5], [5, 6], [9, 8],
-                    [8, 7], [7, 10], [10, 11], [11, 12], [13, 14], [1, 7],
-                    [4, 10]]
+        elif dataset == 'TopDownAicDataset':
+            skeleton = [[2, 1], [1, 0], [0, 13], [13, 3], [3, 4], [4, 5],
+                        [8, 7], [7, 6], [6, 9], [9, 10], [10, 11], [12, 13],
+                        [0, 6], [3, 9]]
 
-        pose_limb_color = palette[[
-            9, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 0, 7, 7
-        ]]
-        pose_kpt_color = palette[[
-            9, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 0, 0
-        ]]
+            pose_link_color = palette[[
+                9, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 0, 7, 7
+            ]]
+            pose_kpt_color = palette[[
+                9, 9, 9, 9, 9, 9, 16, 16, 16, 16, 16, 16, 0, 0
+            ]]
 
-    elif dataset == 'TopDownMpiiDataset':
-        skeleton = [[1, 2], [2, 3], [3, 7], [7, 4], [4, 5], [5, 6], [7, 8],
-                    [8, 9], [9, 10], [9, 13], [13, 12], [12, 11], [9, 14],
-                    [14, 15], [15, 16]]
+        elif dataset == 'TopDownMpiiDataset':
+            skeleton = [[0, 1], [1, 2], [2, 6], [6, 3], [3, 4], [4, 5], [6, 7],
+                        [7, 8], [8, 9], [8, 12], [12, 11], [11, 10], [8, 13],
+                        [13, 14], [14, 15]]
 
-        pose_limb_color = palette[[
-            16, 16, 16, 16, 16, 16, 7, 7, 0, 9, 9, 9, 9, 9, 9
-        ]]
-        pose_kpt_color = palette[[
-            16, 16, 16, 16, 16, 16, 7, 7, 0, 0, 9, 9, 9, 9, 9, 9
-        ]]
+            pose_link_color = palette[[
+                16, 16, 16, 16, 16, 16, 7, 7, 0, 9, 9, 9, 9, 9, 9
+            ]]
+            pose_kpt_color = palette[[
+                16, 16, 16, 16, 16, 16, 7, 7, 0, 0, 9, 9, 9, 9, 9, 9
+            ]]
 
-    elif dataset == 'TopDownMpiiTrbDataset':
-        skeleton = [[13, 14], [14, 1], [14, 2], [1, 3], [2, 4], [3, 5], [4, 6],
-                    [1, 7], [2, 8], [7, 8], [7, 9], [8, 10], [9, 11], [10, 12],
-                    [15, 16], [17, 18], [19, 20], [21, 22], [23, 24], [25, 26],
-                    [27, 28], [29, 30], [31, 32], [33, 34], [35, 36], [37, 38],
-                    [39, 40]]
+        elif dataset == 'TopDownMpiiTrbDataset':
+            skeleton = [[12, 13], [13, 0], [13, 1], [0, 2], [1, 3], [2, 4],
+                        [3, 5], [0, 6], [1, 7], [6, 7], [6, 8], [7,
+                                                                 9], [8, 10],
+                        [9, 11], [14, 15], [16, 17], [18, 19], [20, 21],
+                        [22, 23], [24, 25], [26, 27], [28, 29], [30, 31],
+                        [32, 33], [34, 35], [36, 37], [38, 39]]
 
-        pose_limb_color = palette[[16] * 14 + [19] * 13]
-        pose_kpt_color = palette[[16] * 14 + [0] * 26]
+            pose_link_color = palette[[16] * 14 + [19] * 13]
+            pose_kpt_color = palette[[16] * 14 + [0] * 26]
 
-    elif dataset == 'TopDownH36MDataset':
-        skeleton = [[1, 2], [2, 3], [3, 4], [1, 5], [5, 6], [6, 7], [1, 8],
-                    [8, 9], [9, 10], [10, 11], [9, 12], [12, 13], [13, 14],
-                    [9, 15], [15, 16], [16, 17]]
+        elif dataset in ('OneHand10KDataset', 'FreiHandDataset',
+                         'PanopticDataset'):
+            skeleton = [[0, 1], [1, 2], [2, 3], [3, 4], [0, 5], [5, 6], [6, 7],
+                        [7, 8], [0, 9], [9, 10], [10, 11], [11, 12], [0, 13],
+                        [13, 14], [14, 15], [15, 16], [0, 17], [17, 18],
+                        [18, 19], [19, 20]]
 
-        pose_kpt_color = palette[[
-            9, 0, 0, 0, 16, 16, 16, 9, 9, 9, 9, 16, 16, 16, 0, 0, 0
-        ]]
-        pose_limb_color = palette[[
-            0, 0, 0, 16, 16, 16, 9, 9, 9, 9, 16, 16, 16, 0, 0, 0
-        ]]
+            pose_link_color = palette[[
+                0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16,
+                16
+            ]]
+            pose_kpt_color = palette[[
+                0, 0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16,
+                16, 16
+            ]]
 
-    elif dataset in ('OneHand10KDataset', 'FreiHandDataset',
-                     'PanopticDataset'):
-        skeleton = [[1, 2], [2, 3], [3, 4], [4, 5], [1, 6], [6, 7], [7, 8],
-                    [8, 9], [1, 10], [10, 11], [11, 12], [12, 13], [1, 14],
-                    [14, 15], [15, 16], [16, 17], [1, 18], [18, 19], [19, 20],
-                    [20, 21]]
+        elif dataset == 'InterHand2DDataset':
+            skeleton = [[0, 1], [1, 2], [2, 3], [4, 5], [5, 6], [6, 7], [8, 9],
+                        [9, 10], [10, 11], [12, 13], [13, 14], [14, 15],
+                        [16, 17], [17, 18], [18, 19], [3, 20], [7, 20],
+                        [11, 20], [15, 20], [19, 20]]
 
-        pose_limb_color = palette[[
-            0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16, 16
-        ]]
-        pose_kpt_color = palette[[
-            0, 0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16,
-            16
-        ]]
+            pose_link_color = palette[[
+                0, 0, 0, 4, 4, 4, 8, 8, 8, 12, 12, 12, 16, 16, 16, 0, 4, 8, 12,
+                16
+            ]]
+            pose_kpt_color = palette[[
+                0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16,
+                16, 0
+            ]]
 
-    elif dataset == 'InterHand2DDataset':
-        skeleton = [[1, 2], [2, 3], [3, 4], [5, 6], [6, 7], [7, 8], [9, 10],
-                    [10, 11], [11, 12], [13, 14], [14, 15], [15, 16], [17, 18],
-                    [18, 19], [19, 20], [4, 21], [8, 21], [12, 21], [16, 21],
-                    [20, 21]]
+        elif dataset == 'Face300WDataset':
+            # show the results
+            skeleton = []
 
-        pose_limb_color = palette[[
-            0, 0, 0, 4, 4, 4, 8, 8, 8, 12, 12, 12, 16, 16, 16, 0, 4, 8, 12, 16
-        ]]
-        pose_kpt_color = palette[[
-            0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16, 16,
-            0
-        ]]
+            pose_link_color = palette[[]]
+            pose_kpt_color = palette[[19] * 68]
+            kpt_score_thr = 0
 
-    elif dataset == 'Face300WDataset':
-        # show the results
-        skeleton = []
+        elif dataset == 'FaceAFLWDataset':
+            # show the results
+            skeleton = []
 
-        pose_limb_color = palette[[]]
-        pose_kpt_color = palette[[19] * 68]
-        kpt_score_thr = 0
+            pose_link_color = palette[[]]
+            pose_kpt_color = palette[[19] * 19]
+            kpt_score_thr = 0
 
-    elif dataset == 'FaceAFLWDataset':
-        # show the results
-        skeleton = []
+        elif dataset == 'FaceCOFWDataset':
+            # show the results
+            skeleton = []
 
-        pose_limb_color = palette[[]]
-        pose_kpt_color = palette[[19] * 19]
-        kpt_score_thr = 0
+            pose_link_color = palette[[]]
+            pose_kpt_color = palette[[19] * 29]
+            kpt_score_thr = 0
 
-    elif dataset == 'FaceCOFWDataset':
-        # show the results
-        skeleton = []
+        elif dataset == 'FaceWFLWDataset':
+            # show the results
+            skeleton = []
 
-        pose_limb_color = palette[[]]
-        pose_kpt_color = palette[[19] * 29]
-        kpt_score_thr = 0
+            pose_link_color = palette[[]]
+            pose_kpt_color = palette[[19] * 98]
+            kpt_score_thr = 0
 
-    elif dataset == 'FaceWFLWDataset':
-        # show the results
-        skeleton = []
+        elif dataset == 'AnimalHorse10Dataset':
+            skeleton = [[0, 1], [1, 12], [12, 16], [16, 21], [21, 17],
+                        [17, 11], [11, 10], [10, 8], [8, 9], [9, 12], [2, 3],
+                        [3, 4], [5, 6], [6, 7], [13, 14], [14, 15], [18, 19],
+                        [19, 20]]
 
-        pose_limb_color = palette[[]]
-        pose_kpt_color = palette[[19] * 98]
-        kpt_score_thr = 0
+            pose_link_color = palette[[4] * 10 + [6] * 2 + [6] * 2 + [7] * 2 +
+                                      [7] * 2]
+            pose_kpt_color = palette[[
+                4, 4, 6, 6, 6, 6, 6, 6, 4, 4, 4, 4, 4, 7, 7, 7, 4, 4, 7, 7, 7,
+                4
+            ]]
 
-    elif dataset == 'AnimalHorse10Dataset':
-        skeleton = [[1, 2], [2, 13], [13, 17], [17, 22], [22, 18], [18, 12],
-                    [12, 11], [11, 9], [9, 10], [10, 13], [3, 4], [4, 5],
-                    [6, 7], [7, 8], [14, 15], [15, 16], [19, 20], [20, 21]]
+        elif dataset == 'AnimalFlyDataset':
+            skeleton = [[1, 0], [2, 0], [3, 0], [4, 3], [5, 4], [7, 6], [8, 7],
+                        [9, 8], [11, 10], [12, 11], [13, 12], [15, 14],
+                        [16, 15], [17, 16], [19, 18], [20, 19], [21, 20],
+                        [23, 22], [24, 23], [25, 24], [27, 26], [28, 27],
+                        [29, 28], [30, 3], [31, 3]]
 
-        pose_limb_color = palette[[4] * 10 + [6] * 2 + [6] * 2 + [7] * 2 +
-                                  [7] * 2]
-        pose_kpt_color = palette[[
-            4, 4, 6, 6, 6, 6, 6, 6, 4, 4, 4, 4, 4, 7, 7, 7, 4, 4, 7, 7, 7, 4
-        ]]
+            pose_link_color = palette[[0] * 25]
+            pose_kpt_color = palette[[0] * 32]
 
-    elif dataset == 'AnimalFlyDataset':
-        skeleton = [[2, 1], [3, 1], [4, 1], [5, 4], [6, 5], [8, 7], [9, 8],
-                    [10, 9], [12, 11], [13, 12], [14, 13], [16, 15], [17, 16],
-                    [18, 17], [20, 19], [21, 20], [22, 21], [24, 23], [25, 24],
-                    [26, 25], [28, 27], [29, 28], [30, 29], [31, 4], [32, 4]]
+        elif dataset == 'AnimalLocustDataset':
+            skeleton = [[1, 0], [2, 1], [3, 2], [4, 3], [6, 5], [7, 6], [9, 8],
+                        [10, 9], [11, 10], [13, 12], [14, 13], [15, 14],
+                        [17, 16], [18, 17], [19, 18], [21, 20], [22, 21],
+                        [24, 23], [25, 24], [26, 25], [28, 27], [29, 28],
+                        [30, 29], [32, 31], [33, 32], [34, 33]]
 
-        pose_limb_color = palette[[0] * 25]
-        pose_kpt_color = palette[[0] * 32]
+            pose_link_color = palette[[0] * 26]
+            pose_kpt_color = palette[[0] * 35]
 
-    elif dataset == 'AnimalLocustDataset':
-        skeleton = [[2, 1], [3, 2], [4, 3], [5, 4], [7, 6], [8, 7], [10, 9],
-                    [11, 10], [12, 11], [14, 13], [15, 14], [16, 15], [18, 17],
-                    [19, 18], [20, 19], [22, 21], [23, 22], [25, 24], [26, 25],
-                    [27, 26], [29, 28], [30, 29], [31, 30], [33, 32], [34, 33],
-                    [35, 34]]
+        elif dataset == 'AnimalZebraDataset':
+            skeleton = [[1, 0], [2, 1], [3, 2], [4, 2], [5, 7], [6, 7], [7, 2],
+                        [8, 7]]
 
-        pose_limb_color = palette[[0] * 26]
-        pose_kpt_color = palette[[0] * 35]
+            pose_link_color = palette[[0] * 8]
+            pose_kpt_color = palette[[0] * 9]
 
-    elif dataset == 'AnimalZebraDataset':
-        skeleton = [[2, 1], [3, 2], [4, 3], [5, 3], [6, 8], [7, 8], [8, 3],
-                    [9, 8]]
+        elif dataset in 'AnimalPoseDataset':
+            skeleton = [[0, 1], [0, 2], [1, 3], [0, 4], [1, 4], [4, 5], [5, 7],
+                        [6, 7], [5, 8], [8, 12], [12, 16], [5, 9], [9, 13],
+                        [13, 17], [6, 10], [10, 14], [14, 18], [6, 11],
+                        [11, 15], [15, 19]]
 
-        pose_limb_color = palette[[0] * 8]
-        pose_kpt_color = palette[[0] * 9]
+            pose_link_color = palette[[0] * 20]
+            pose_kpt_color = palette[[0] * 20]
+        else:
+            NotImplementedError()
 
-    elif dataset in 'AnimalPoseDataset':
-        skeleton = [[1, 2], [1, 3], [2, 4], [1, 5], [2, 5], [5, 6], [6, 8],
-                    [7, 8], [6, 9], [9, 13], [13, 17], [6, 10], [10, 14],
-                    [14, 18], [7, 11], [11, 15], [15, 19], [7, 12], [12, 16],
-                    [16, 20]]
-
-        pose_kpt_color = palette[[15] * 5 + [0] * 7 + [9] * 8]
-        pose_limb_color = palette[[15] * 5 + [0] * 3 + [0, 9, 9] * 4]
-
-    else:
-        raise NotImplementedError()
+    if hasattr(model, 'module'):
+        model = model.module
 
     img = model.show_result(
         img,
@@ -755,7 +798,7 @@ def vis_pose_result(model,
         radius=radius,
         thickness=thickness,
         pose_kpt_color=pose_kpt_color,
-        pose_limb_color=pose_limb_color,
+        pose_link_color=pose_link_color,
         kpt_score_thr=kpt_score_thr,
         bbox_color=bbox_color,
         show=show,
@@ -770,7 +813,6 @@ def process_mmdet_results(mmdet_results, cat_id=1):
     Args:
         mmdet_results (list|tuple): mmdet results.
         cat_id (int): category id (default: 1 for human)
-
     Returns:
         person_results (list): a list of detected bounding boxes
     """
