@@ -1,4 +1,6 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+import warnings
+
 import numpy as np
 import torch
 from mmcv.parallel import collate, scatter
@@ -203,7 +205,8 @@ def _collate_pose_sequence(pose_results, with_track_id=True, target_frame=-1):
 
 def inference_pose_lifter_model(model,
                                 pose_results_2d,
-                                dataset,
+                                dataset=None,
+                                dataset_info=None,
                                 with_track_id=True,
                                 image_size=None,
                                 norm_pose_2d=False):
@@ -241,13 +244,24 @@ def inference_pose_lifter_model(model,
     cfg = model.cfg
     test_pipeline = Compose(cfg.test_pipeline)
 
-    flip_pairs = None
-    if dataset == 'Body3DH36MDataset':
-        flip_pairs = [[1, 4], [2, 5], [3, 6], [11, 14], [12, 15], [13, 16]]
-        bbox_center = np.array([[528, 427]], dtype=np.float32)
-        bbox_scale = 400
+    if dataset_info is not None:
+        flip_pairs = dataset_info.flip_pairs
+        assert 'stats_info' in dataset_info._dataset_info
+        bbox_center = dataset_info._dataset_info['stats_info']['bbox_center']
+        bbox_scale = dataset_info._dataset_info['stats_info']['bbox_scale']
     else:
-        raise NotImplementedError()
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        # TODO: These will be removed in the later versions.
+        if dataset == 'Body3DH36MDataset':
+            flip_pairs = [[1, 4], [2, 5], [3, 6], [11, 14], [12, 15], [13, 16]]
+            bbox_center = np.array([[528, 427]], dtype=np.float32)
+            bbox_scale = 400
+        else:
+            raise NotImplementedError()
 
     target_idx = -1 if model.causal else len(pose_results_2d) // 2
     pose_lifter_inputs = _gather_pose_lifter_inputs(pose_results_2d,
@@ -271,6 +285,7 @@ def inference_pose_lifter_model(model,
         else:
             input_2d_visible = np.ones((T, K, 1), dtype=np.float32)
 
+        # TODO: Will be removed in the later versions
         # Dummy 3D input
         # This is for compatibility with configs in mmpose<=v0.14.0, where a
         # 3D input is required to generate denormalization parameters. This
@@ -336,6 +351,7 @@ def vis_3d_pose_result(model,
                        result,
                        img=None,
                        dataset='Body3DH36MDataset',
+                       dataset_info=None,
                        kpt_score_thr=0.3,
                        radius=8,
                        thickness=2,
@@ -348,69 +364,84 @@ def vis_3d_pose_result(model,
         model (nn.Module): The loaded model.
         result (list[dict])
     """
+
+    if dataset_info is not None:
+        skeleton = dataset_info.skeleton
+        pose_kpt_color = dataset_info.pose_kpt_color
+        pose_link_color = dataset_info.pose_link_color
+    else:
+        warnings.warn(
+            'dataset is deprecated.'
+            'Please set `dataset_info` in the config.'
+            'Check https://github.com/open-mmlab/mmpose/pull/663 for details.',
+            DeprecationWarning)
+        # TODO: These will be removed in the later versions.
+        palette = np.array([[255, 128, 0], [255, 153, 51], [255, 178, 102],
+                            [230, 230, 0], [255, 153, 255], [153, 204, 255],
+                            [255, 102, 255], [255, 51, 255], [102, 178, 255],
+                            [51, 153, 255], [255, 153, 153], [255, 102, 102],
+                            [255, 51, 51], [153, 255, 153], [102, 255, 102],
+                            [51, 255, 51], [0, 255, 0], [0, 0, 255],
+                            [255, 0, 0], [255, 255, 255]])
+
+        if dataset == 'Body3DH36MDataset':
+            skeleton = [[0, 1], [1, 2], [2, 3], [0, 4], [4, 5], [5, 6], [0, 7],
+                        [7, 8], [8, 9], [9, 10], [8, 11], [11, 12], [12, 13],
+                        [8, 14], [14, 15], [15, 16]]
+
+            pose_kpt_color = palette[[
+                9, 0, 0, 0, 16, 16, 16, 9, 9, 9, 9, 16, 16, 16, 0, 0, 0
+            ]]
+            pose_link_color = palette[[
+                0, 0, 0, 16, 16, 16, 9, 9, 9, 9, 16, 16, 16, 0, 0, 0
+            ]]
+
+        elif dataset == 'InterHand3DDataset':
+            skeleton = [[0, 1], [1, 2], [2, 3], [3, 20], [4, 5], [5, 6],
+                        [6, 7], [7, 20], [8, 9], [9, 10], [10, 11], [11, 20],
+                        [12, 13], [13, 14], [14, 15], [15, 20], [16, 17],
+                        [17, 18], [18, 19], [19, 20], [21, 22], [22, 23],
+                        [23, 24], [24, 41], [25, 26], [26, 27], [27, 28],
+                        [28, 41], [29, 30], [30, 31], [31, 32], [32, 41],
+                        [33, 34], [34, 35], [35, 36], [36, 41], [37, 38],
+                        [38, 39], [39, 40], [40, 41]]
+
+            pose_kpt_color = [[14, 128, 250], [14, 128, 250], [14, 128, 250],
+                              [14, 128, 250], [80, 127, 255], [80, 127, 255],
+                              [80, 127, 255], [80, 127, 255], [71, 99, 255],
+                              [71, 99, 255], [71, 99, 255], [71, 99, 255],
+                              [0, 36, 255], [0, 36, 255], [0, 36, 255],
+                              [0, 36, 255], [0, 0, 230], [0, 0, 230],
+                              [0, 0, 230], [0, 0, 230], [0, 0, 139],
+                              [237, 149, 100], [237, 149, 100],
+                              [237, 149, 100], [237, 149, 100], [230, 128, 77],
+                              [230, 128, 77], [230, 128, 77], [230, 128, 77],
+                              [255, 144, 30], [255, 144, 30], [255, 144, 30],
+                              [255, 144, 30], [153, 51, 0], [153, 51, 0],
+                              [153, 51, 0], [153, 51, 0], [255, 51, 13],
+                              [255, 51, 13], [255, 51, 13], [255, 51, 13],
+                              [103, 37, 8]]
+
+            pose_link_color = [[14, 128, 250], [14, 128, 250], [14, 128, 250],
+                               [14, 128, 250], [80, 127, 255], [80, 127, 255],
+                               [80, 127, 255], [80, 127, 255], [71, 99, 255],
+                               [71, 99, 255], [71, 99, 255], [71, 99, 255],
+                               [0, 36, 255], [0, 36, 255], [0, 36, 255],
+                               [0, 36, 255], [0, 0, 230], [0, 0, 230],
+                               [0, 0, 230], [0, 0, 230], [237, 149, 100],
+                               [237, 149, 100], [237, 149, 100],
+                               [237, 149, 100], [230, 128, 77], [230, 128, 77],
+                               [230, 128, 77], [230, 128, 77], [255, 144, 30],
+                               [255, 144, 30], [255, 144, 30], [255, 144, 30],
+                               [153, 51, 0], [153, 51, 0], [153, 51, 0],
+                               [153, 51, 0], [255, 51, 13], [255, 51, 13],
+                               [255, 51, 13], [255, 51, 13]]
+        else:
+            raise NotImplementedError
+
     if hasattr(model, 'module'):
         model = model.module
 
-    palette = np.array([[255, 128, 0], [255, 153, 51], [255, 178, 102],
-                        [230, 230, 0], [255, 153, 255], [153, 204, 255],
-                        [255, 102, 255], [255, 51, 255], [102, 178, 255],
-                        [51, 153, 255], [255, 153, 153], [255, 102, 102],
-                        [255, 51, 51], [153, 255, 153], [102, 255, 102],
-                        [51, 255, 51], [0, 255, 0], [0, 0, 255], [255, 0, 0],
-                        [255, 255, 255]])
-
-    if dataset == 'Body3DH36MDataset':
-        skeleton = [[1, 2], [2, 3], [3, 4], [1, 5], [5, 6], [6, 7], [1, 8],
-                    [8, 9], [9, 10], [10, 11], [9, 12], [12, 13], [13, 14],
-                    [9, 15], [15, 16], [16, 17]]
-
-        pose_kpt_color = palette[[
-            9, 0, 0, 0, 16, 16, 16, 9, 9, 9, 9, 16, 16, 16, 0, 0, 0
-        ]]
-        pose_limb_color = palette[[
-            0, 0, 0, 16, 16, 16, 9, 9, 9, 9, 16, 16, 16, 0, 0, 0
-        ]]
-    elif dataset == 'InterHand3DDataset':
-        skeleton = [[1, 2], [2, 3], [3, 4], [4, 21], [5, 6], [6, 7], [7, 8],
-                    [8, 21], [9, 10], [10, 11], [11, 12], [12, 21], [13, 14],
-                    [14, 15], [15, 16], [16, 21], [17, 18], [18, 19], [19, 20],
-                    [20, 21], [22, 23], [23, 24], [24, 25], [25, 42], [26, 27],
-                    [27, 28], [28, 29], [29, 42], [30, 31], [31, 32], [32, 33],
-                    [33, 42], [34, 35], [35, 36], [36, 37], [37, 42], [38, 39],
-                    [39, 40], [40, 41], [41, 42]]
-
-        pose_kpt_color = [[14, 128, 250], [14, 128, 250], [14, 128, 250],
-                          [14, 128, 250], [80, 127, 255], [80, 127, 255],
-                          [80, 127, 255], [80, 127, 255], [71, 99, 255],
-                          [71, 99, 255], [71, 99, 255], [71, 99, 255],
-                          [0, 36, 255], [0, 36, 255], [0, 36, 255],
-                          [0, 36, 255], [0, 0, 230], [0, 0, 230], [0, 0, 230],
-                          [0, 0, 230], [0, 0, 139], [237, 149, 100],
-                          [237, 149, 100], [237, 149, 100], [237, 149, 100],
-                          [230, 128, 77], [230, 128, 77], [230, 128, 77],
-                          [230, 128, 77], [255, 144, 30], [255, 144, 30],
-                          [255, 144, 30], [255, 144, 30], [153, 51, 0],
-                          [153, 51, 0], [153, 51, 0], [153, 51, 0],
-                          [255, 51, 13], [255, 51, 13], [255, 51, 13],
-                          [255, 51, 13], [103, 37, 8]]
-
-        pose_limb_color = [[14, 128, 250], [14, 128, 250], [14, 128, 250],
-                           [14, 128, 250], [80, 127, 255], [80, 127, 255],
-                           [80, 127, 255], [80, 127, 255], [71, 99, 255],
-                           [71, 99, 255], [71, 99, 255], [71, 99, 255],
-                           [0, 36, 255], [0, 36, 255], [0, 36, 255],
-                           [0, 36, 255], [0, 0, 230], [0, 0, 230], [0, 0, 230],
-                           [0, 0, 230], [237, 149, 100], [237, 149, 100],
-                           [237, 149, 100], [237, 149, 100], [230, 128, 77],
-                           [230, 128, 77], [230, 128, 77], [230, 128, 77],
-                           [255, 144, 30], [255, 144, 30], [255, 144, 30],
-                           [255, 144, 30], [153, 51, 0], [153, 51, 0],
-                           [153, 51, 0], [153, 51, 0], [255, 51, 13],
-                           [255, 51, 13], [255, 51, 13], [255, 51, 13]]
-
-    else:
-        raise NotImplementedError
-
     img = model.show_result(
         result,
         img,
@@ -418,7 +449,7 @@ def vis_3d_pose_result(model,
         radius=radius,
         thickness=thickness,
         pose_kpt_color=pose_kpt_color,
-        pose_limb_color=pose_limb_color,
+        pose_link_color=pose_link_color,
         num_instances=num_instances,
         show=show,
         out_file=out_file)
@@ -590,12 +621,10 @@ def inference_mesh_model(model,
                          format='xywh',
                          dataset='MeshH36MDataset'):
     """Inference a single image with a list of bounding boxes.
-
     num_bboxes: N
     num_keypoints: K
     num_vertices: V
     num_faces: F
-
     Args:
         model (nn.Module): The loaded pose model.
         img_or_path (str | np.ndarray): Image filename or loaded image.
@@ -610,7 +639,6 @@ def inference_mesh_model(model,
             'xyxy' means (left, top, right, bottom),
             'xywh' means (left, top, width, height).
         dataset (str): Dataset name.
-
     Returns:
         List[dict]: 3D pose inference results. Each element is the result of
             an instance, which contains:
@@ -621,7 +649,6 @@ def inference_mesh_model(model,
             - "camera" (ndarray[3]): camera parameters
             - "vertices" (ndarray[V, 3]): predicted 3D vertices
             - "faces" (ndarray[F, 3]): mesh faces
-
             If there is no valid instance, an empty list will be returned.
     """
 
