@@ -8,11 +8,12 @@ from .body3d import Body3DH36MDataset
 from .bottom_up import (BottomUpAicDataset, BottomUpCocoDataset,
                         BottomUpCocoWholeBodyDataset, BottomUpCrowdPoseDataset,
                         BottomUpMhpDataset)
-from .face import (Face300WDataset, FaceAFLWDataset, FaceCOFWDataset,
-                   FaceWFLWDataset)
+from .face import (Face300WDataset, FaceAFLWDataset, FaceCocoWholeBodyDataset,
+                   FaceCOFWDataset, FaceWFLWDataset)
 from .fashion import DeepFashionDataset
-from .hand import (FreiHandDataset, InterHand2DDataset, InterHand3DDataset,
-                   OneHand10KDataset, PanopticDataset)
+from .hand import (FreiHandDataset, HandCocoWholeBodyDataset,
+                   InterHand2DDataset, InterHand3DDataset, OneHand10KDataset,
+                   PanopticDataset)
 from .mesh import (MeshAdversarialDataset, MeshH36MDataset, MeshMixDataset,
                    MoshDataset)
 from .top_down import (TopDownAicDataset, TopDownCocoDataset,
@@ -26,16 +27,16 @@ __all__ = [
     'TopDownCocoDataset', 'BottomUpCocoDataset', 'BottomUpMhpDataset',
     'BottomUpAicDataset', 'BottomUpCocoWholeBodyDataset', 'TopDownMpiiDataset',
     'TopDownMpiiTrbDataset', 'OneHand10KDataset', 'PanopticDataset',
-    'FreiHandDataset', 'InterHand2DDataset', 'InterHand3DDataset',
-    'TopDownOCHumanDataset', 'TopDownAicDataset',
+    'HandCocoWholeBodyDataset', 'FreiHandDataset', 'InterHand2DDataset',
+    'InterHand3DDataset', 'TopDownOCHumanDataset', 'TopDownAicDataset',
     'TopDownCocoWholeBodyDataset', 'MeshH36MDataset', 'MeshMixDataset',
     'MoshDataset', 'MeshAdversarialDataset', 'TopDownCrowdPoseDataset',
     'BottomUpCrowdPoseDataset', 'TopDownFreiHandDataset',
     'TopDownOneHand10KDataset', 'TopDownPanopticDataset',
     'TopDownPoseTrack18Dataset', 'TopDownJhmdbDataset', 'TopDownMhpDataset',
     'DeepFashionDataset', 'Face300WDataset', 'FaceAFLWDataset',
-    'FaceWFLWDataset', 'FaceCOFWDataset', 'Body3DH36MDataset',
-    'AnimalHorse10Dataset', 'AnimalMacaqueDataset', 'AnimalFlyDataset',
-    'AnimalLocustDataset', 'AnimalZebraDataset', 'AnimalATRWDataset',
-    'AnimalPoseDataset', 'TopDownH36MDataset'
+    'FaceWFLWDataset', 'FaceCOFWDataset', 'FaceCocoWholeBodyDataset',
+    'Body3DH36MDataset', 'AnimalHorse10Dataset', 'AnimalMacaqueDataset',
+    'AnimalFlyDataset', 'AnimalLocustDataset', 'AnimalZebraDataset',
+    'AnimalATRWDataset', 'AnimalPoseDataset', 'TopDownH36MDataset'
 ]
