@@ -1,18 +1,20 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os.path as osp
+import warnings
 from collections import OrderedDict, defaultdict
 
 import mmcv
 import numpy as np
+from mmcv import Config
 
 from mmpose.core.evaluation import (keypoint_3d_auc, keypoint_3d_pck,
                                     keypoint_mpjpe)
+from mmpose.datasets.datasets.base import Kpt3dSviewKpt2dDataset
 from ...builder import DATASETS
-from .body3d_base_dataset import Body3DBaseDataset
 
 
 @DATASETS.register_module()
-class Body3DMpiInf3dhpDataset(Body3DBaseDataset):
+class Body3DMpiInf3dhpDataset(Kpt3dSviewKpt2dDataset):
     """MPI-INF-3DHP dataset for 3D human pose estimation.
 
     `Monocular 3D Human Pose Estimation In The Wild Using Improved CNN
@@ -56,6 +58,7 @@ class Body3DMpiInf3dhpDataset(Body3DBaseDataset):
             - need_camera_param: Whether need camera parameters or not.
                 Default: False.
         pipeline (list[dict | callable]): A sequence of data transforms.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         test_mode (bool): Store True when building test or
             validation dataset. Default: False.
     """
@@ -77,6 +80,30 @@ class Body3DMpiInf3dhpDataset(Body3DBaseDataset):
         'mpjpe', 'p-mpjpe', '3dpck', 'p-3dpck', '3dauc', 'p-3dauc'
     }
 
+    def __init__(self,
+                 ann_file,
+                 img_prefix,
+                 data_cfg,
+                 pipeline,
+                 dataset_info=None,
+                 test_mode=False):
+
+        if dataset_info is None:
+            warnings.warn(
+                'dataset_info is missing. '
+                'Check https://github.com/open-mmlab/mmpose/pull/663 '
+                'for details.', DeprecationWarning)
+            cfg = Config.fromfile('configs/_base_/datasets/mpi_inf_3dhp.py')
+            dataset_info = cfg._cfg_dict['dataset_info']
+
+        super().__init__(
+            ann_file,
+            img_prefix,
+            data_cfg,
+            pipeline,
+            dataset_info=dataset_info,
+            test_mode=test_mode)
+
     def load_config(self, data_cfg):
         super().load_config(data_cfg)
         # mpi-inf-3dhp specific attributes
@@ -96,10 +123,6 @@ class Body3DMpiInf3dhpDataset(Body3DBaseDataset):
 
         # mpi-inf-3dhp specific annotation info
         ann_info = {}
-        ann_info['flip_pairs'] = [[2, 5], [3, 6], [4, 7], [8, 11], [9, 12],
-                                  [10, 13]]
-        ann_info['upper_body_ids'] = (0, 1, 2, 3, 4, 5, 6, 7, 14, 15, 16)
-        ann_info['lower_body_ids'] = (8, 9, 10, 11, 12, 13)
         ann_info['use_different_joint_weights'] = False
 
         self.ann_info.update(ann_info)
