@@ -1,7 +1,8 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+import warnings
+
 import json_tricks as json
-import numpy as np
-from xtcocotools.coco import COCO
+from mmcv import Config
 from xtcocotools.cocoeval import COCOeval
 
 from mmpose.datasets.builder import DATASETS
@@ -40,6 +41,7 @@ class BottomUpAicDataset(BottomUpCocoDataset):
             Default: None.
         data_cfg (dict): config
         pipeline (list[dict | callable]): A sequence of data transforms.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         test_mode (bool): Store True when building test or
             validation dataset. Default: False.
     """
@@ -49,45 +51,26 @@ class BottomUpAicDataset(BottomUpCocoDataset):
                  img_prefix,
                  data_cfg,
                  pipeline,
+                 dataset_info=None,
                  test_mode=False):
+
+        if dataset_info is None:
+            warnings.warn(
+                'dataset_info is missing. '
+                'Check https://github.com/open-mmlab/mmpose/pull/663 '
+                'for details.', DeprecationWarning)
+            cfg = Config.fromfile('configs/_base_/datasets/aic.py')
+            dataset_info = cfg._cfg_dict['dataset_info']
+
         super(BottomUpCocoDataset, self).__init__(
-            ann_file, img_prefix, data_cfg, pipeline, test_mode=test_mode)
+            ann_file,
+            img_prefix,
+            data_cfg,
+            pipeline,
+            dataset_info=dataset_info,
+            test_mode=test_mode)
 
-        self.ann_info['flip_index'] = [
-            3, 4, 5, 0, 1, 2, 9, 10, 11, 6, 7, 8, 12, 13
-        ]
         self.ann_info['use_different_joint_weights'] = False
-        self.ann_info['joint_weights'] = np.array(
-            [1., 1.2, 1.5, 1., 1.2, 1.5, 1., 1.2, 1.5, 1., 1.2, 1.5, 1., 1.],
-            dtype=np.float32).reshape((self.ann_info['num_joints'], 1))
-
-        self.sigmas = np.array([
-            0.01388152, 0.01515228, 0.01057665, 0.01417709, 0.01497891,
-            0.01402144, 0.03909642, 0.03686941, 0.01981803, 0.03843971,
-            0.03412318, 0.02415081, 0.01291456, 0.01236173
-        ])
-        self.coco = COCO(ann_file)
-
-        cats = [
-            cat['name'] for cat in self.coco.loadCats(self.coco.getCatIds())
-        ]
-        self.classes = ['__background__'] + cats
-        self.num_classes = len(self.classes)
-        self._class_to_ind = dict(zip(self.classes, range(self.num_classes)))
-        self._class_to_coco_ind = dict(zip(cats, self.coco.getCatIds()))
-        self._coco_ind_to_class_ind = dict(
-            (self._class_to_coco_ind[cls], self._class_to_ind[cls])
-            for cls in self.classes[1:])
-        self.img_ids = self.coco.getImgIds()
-        if not test_mode:
-            self.img_ids = [
-                img_id for img_id in self.img_ids
-                if len(self.coco.getAnnIds(imgIds=img_id, iscrowd=None)) > 0
-            ]
-        self.num_images = len(self.img_ids)
-        self.id2name, self.name2id = self._get_mapping_id_name(self.coco.imgs)
-        self.dataset_name = 'aic'
-
         print(f'=> num_images: {self.num_images}')
 
     def _do_python_keypoint_eval(self, res_file):
