@@ -3,7 +3,7 @@ import os
 import warnings
 
 import numpy as np
-from xtcocotools.coco import COCO
+from mmcv import Config
 from xtcocotools.cocoeval import COCOeval
 
 from ...builder import DATASETS
@@ -35,6 +35,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
             Default: None.
         data_cfg (dict): config
         pipeline (list[dict | callable]): A sequence of data transforms.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         test_mode (bool): Store True when building test or
             validation dataset. Default: False.
     """
@@ -44,115 +45,45 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
                  img_prefix,
                  data_cfg,
                  pipeline,
+                 dataset_info=None,
                  test_mode=False):
+
+        if dataset_info is None:
+            warnings.warn(
+                'dataset_info is missing. '
+                'Check https://github.com/open-mmlab/mmpose/pull/663 '
+                'for details.', DeprecationWarning)
+            cfg = Config.fromfile('configs/_base_/datasets/coco_wholebody.py')
+            dataset_info = cfg._cfg_dict['dataset_info']
+
         super(TopDownCocoDataset, self).__init__(
-            ann_file, img_prefix, data_cfg, pipeline, test_mode=test_mode)
+            ann_file,
+            img_prefix,
+            data_cfg,
+            pipeline,
+            dataset_info=dataset_info,
+            test_mode=test_mode)
 
         self.use_gt_bbox = data_cfg['use_gt_bbox']
         self.bbox_file = data_cfg['bbox_file']
         self.det_bbox_thr = data_cfg.get('det_bbox_thr', 0.0)
-        if 'image_thr' in data_cfg:
-            warnings.warn(
-                'image_thr is deprecated, '
-                'please use det_bbox_thr instead', DeprecationWarning)
-            self.det_bbox_thr = data_cfg['image_thr']
         self.use_nms = data_cfg.get('use_nms', True)
         self.soft_nms = data_cfg['soft_nms']
         self.nms_thr = data_cfg['nms_thr']
         self.oks_thr = data_cfg['oks_thr']
         self.vis_thr = data_cfg['vis_thr']
 
-        self.ann_info['flip_pairs'] = self._make_flip_pairs()
-
-        self.ann_info['upper_body_ids'] = (0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10)
-        self.ann_info['lower_body_ids'] = (11, 12, 13, 14, 15, 16)
-
-        self.ann_info['use_different_joint_weights'] = False
-        self.ann_info['joint_weights'] = \
-            np.ones((self.ann_info['num_joints'], 1), dtype=np.float32)
-
         self.body_num = 17
         self.foot_num = 6
         self.face_num = 68
         self.left_hand_num = 21
         self.right_hand_num = 21
 
-        # 'https://github.com/jin-s13/COCO-WholeBody/blob/master/'
-        # 'evaluation/myeval_wholebody.py#L170'
-        self.sigmas_body = [
-            0.026, 0.025, 0.025, 0.035, 0.035, 0.079, 0.079, 0.072, 0.072,
-            0.062, 0.062, 0.107, 0.107, 0.087, 0.087, 0.089, 0.089
-        ]
-        self.sigmas_foot = [0.068, 0.066, 0.066, 0.092, 0.094, 0.094]
-        self.sigmas_face = [
-            0.042, 0.043, 0.044, 0.043, 0.040, 0.035, 0.031, 0.025, 0.020,
-            0.023, 0.029, 0.032, 0.037, 0.038, 0.043, 0.041, 0.045, 0.013,
-            0.012, 0.011, 0.011, 0.012, 0.012, 0.011, 0.011, 0.013, 0.015,
-            0.009, 0.007, 0.007, 0.007, 0.012, 0.009, 0.008, 0.016, 0.010,
-            0.017, 0.011, 0.009, 0.011, 0.009, 0.007, 0.013, 0.008, 0.011,
-            0.012, 0.010, 0.034, 0.008, 0.008, 0.009, 0.008, 0.008, 0.007,
-            0.010, 0.008, 0.009, 0.009, 0.009, 0.007, 0.007, 0.008, 0.011,
-            0.008, 0.008, 0.008, 0.01, 0.008
-        ]
-        self.sigmas_lefthand = [
-            0.029, 0.022, 0.035, 0.037, 0.047, 0.026, 0.025, 0.024, 0.035,
-            0.018, 0.024, 0.022, 0.026, 0.017, 0.021, 0.021, 0.032, 0.02,
-            0.019, 0.022, 0.031
-        ]
-        self.sigmas_righthand = [
-            0.029, 0.022, 0.035, 0.037, 0.047, 0.026, 0.025, 0.024, 0.035,
-            0.018, 0.024, 0.022, 0.026, 0.017, 0.021, 0.021, 0.032, 0.02,
-            0.019, 0.022, 0.031
-        ]
-
-        self.sigmas_wholebody = (
-            self.sigmas_body + self.sigmas_foot + self.sigmas_face +
-            self.sigmas_lefthand + self.sigmas_righthand)
-
-        self.sigmas = np.array(self.sigmas_wholebody)
-
-        self.coco = COCO(ann_file)
-
-        cats = [
-            cat['name'] for cat in self.coco.loadCats(self.coco.getCatIds())
-        ]
-        self.classes = ['__background__'] + cats
-        self.num_classes = len(self.classes)
-        self._class_to_ind = dict(zip(self.classes, range(self.num_classes)))
-        self._class_to_coco_ind = dict(zip(cats, self.coco.getCatIds()))
-        self._coco_ind_to_class_ind = dict(
-            (self._class_to_coco_ind[cls], self._class_to_ind[cls])
-            for cls in self.classes[1:])
-        self.img_ids = self.coco.getImgIds()
-        self.num_images = len(self.img_ids)
-        self.id2name, self.name2id = self._get_mapping_id_name(self.coco.imgs)
-        self.dataset_name = 'coco_wholebody'
-
         self.db = self._get_db()
 
         print(f'=> num_images: {self.num_images}')
         print(f'=> load {len(self.db)} samples')
 
-    @staticmethod
-    def _make_flip_pairs():
-        body = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12], [13, 14],
-                [15, 16]]
-        foot = [[17, 20], [18, 21], [19, 22]]
-
-        face = [[23, 39], [24, 38], [25, 37], [26, 36], [27, 35], [28, 34],
-                [29, 33], [30, 32], [40, 49], [41, 48], [42, 47], [43, 46],
-                [44, 45], [54, 58], [55, 57], [59, 68], [60, 67], [61, 66],
-                [62, 65], [63, 70], [64, 69], [71, 77], [72, 76], [73, 75],
-                [78, 82], [79, 81], [83, 87], [84, 86], [88, 90]]
-
-        hand = [[91, 112], [92, 113], [93, 114], [94, 115], [95, 116],
-                [96, 117], [97, 118], [98, 119], [99, 120], [100, 121],
-                [101, 122], [102, 123], [103, 124], [104, 125], [105, 126],
-                [106, 127], [107, 128], [108, 129], [109, 130], [110, 131],
-                [111, 132]]
-
-        return body + foot + face + hand
-
     def _load_coco_keypoint_annotation_kernel(self, img_id):
         """load annotation from COCOAPI.
 
@@ -257,11 +188,16 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
         """Keypoint evaluation using COCOAPI."""
         coco_det = self.coco.loadRes(res_file)
 
+        cuts = np.cumsum([
+            0, self.body_num, self.foot_num, self.face_num, self.left_hand_num,
+            self.right_hand_num
+        ])
+
         coco_eval = COCOeval(
             self.coco,
             coco_det,
             'keypoints_body',
-            np.array(self.sigmas_body),
+            self.sigmas[cuts[0]:cuts[1]],
             use_area=True)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
@@ -272,7 +208,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
             self.coco,
             coco_det,
             'keypoints_foot',
-            np.array(self.sigmas_foot),
+            self.sigmas[cuts[1]:cuts[2]],
             use_area=True)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
@@ -283,7 +219,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
             self.coco,
             coco_det,
             'keypoints_face',
-            np.array(self.sigmas_face),
+            self.sigmas[cuts[2]:cuts[3]],
             use_area=True)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
@@ -294,7 +230,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
             self.coco,
             coco_det,
             'keypoints_lefthand',
-            np.array(self.sigmas_lefthand),
+            self.sigmas[cuts[3]:cuts[4]],
             use_area=True)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
@@ -305,7 +241,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
             self.coco,
             coco_det,
             'keypoints_righthand',
-            np.array(self.sigmas_righthand),
+            self.sigmas[cuts[4]:cuts[5]],
             use_area=True)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
@@ -316,7 +252,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
             self.coco,
             coco_det,
             'keypoints_wholebody',
-            np.array(self.sigmas_wholebody),
+            self.sigmas,
             use_area=True)
         coco_eval.params.useSegm = None
         coco_eval.evaluate()
