@@ -1,19 +1,18 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import os
+import warnings
 from collections import OrderedDict
 
 import json_tricks as json
 import numpy as np
-from xtcocotools.coco import COCO
+from mmcv import Config
 
-from mmpose.core.evaluation.top_down_eval import (keypoint_epe,
-                                                  keypoint_pck_accuracy)
 from ...builder import DATASETS
-from .topdown_base_dataset import TopDownBaseDataset
+from ..base import Kpt2dSviewRgbImgTopDownDataset
 
 
 @DATASETS.register_module()
-class TopDownH36MDataset(TopDownBaseDataset):
+class TopDownH36MDataset(Kpt2dSviewRgbImgTopDownDataset):
     """Human3.6M dataset for top-down 2D pose estimation.
 
     `Human3.6M: Large Scale Datasets and Predictive Methods for 3D Human
@@ -46,6 +45,7 @@ class TopDownH36MDataset(TopDownBaseDataset):
             Default: None.
         data_cfg (dict): config
         pipeline (list[dict | callable]): A sequence of data transforms.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         test_mode (bool): Store True when building test or
             validation dataset. Default: False.
     """
@@ -55,83 +55,30 @@ class TopDownH36MDataset(TopDownBaseDataset):
                  img_prefix,
                  data_cfg,
                  pipeline,
+                 dataset_info=None,
                  test_mode=False):
-        super(TopDownH36MDataset, self).__init__(
-            ann_file, img_prefix, data_cfg, pipeline, test_mode=test_mode)
 
-        assert self.ann_info['num_joints'] == 17
+        if dataset_info is None:
+            warnings.warn(
+                'dataset_info is missing. '
+                'Check https://github.com/open-mmlab/mmpose/pull/663 '
+                'for details.', DeprecationWarning)
+            cfg = Config.fromfile('configs/_base_/datasets/h36m.py')
+            dataset_info = cfg._cfg_dict['dataset_info']
 
-        self.ann_info['flip_pairs'] = [[1, 4], [2, 5], [3, 6], [11, 14],
-                                       [12, 15], [13, 16]]
-        self.ann_info['upper_body_ids'] = (0, 7, 8, 9, 10, 11, 12, 13, 14, 15,
-                                           16)
-        self.ann_info['lower_body_ids'] = (1, 2, 3, 4, 5, 6)
-        self.ann_info['use_different_joint_weights'] = False
+        super().__init__(
+            ann_file,
+            img_prefix,
+            data_cfg,
+            pipeline,
+            dataset_info=dataset_info,
+            test_mode=test_mode)
 
-        self.ann_info['joint_weights'] = np.ones(
-            (self.ann_info['num_joints'], 1), dtype=np.float32)
-
-        self.coco = COCO(ann_file)
-        self.img_ids = self.coco.getImgIds()
-        self.num_images = len(self.img_ids)
-        self.id2name, self.name2id = self._get_mapping_id_name(self.coco.imgs)
-
-        self.dataset_name = 'h36m'
         self.db = self._get_db()
 
         print(f'=> num_images: {self.num_images}')
         print(f'=> load {len(self.db)} samples')
 
-    @staticmethod
-    def _get_mapping_id_name(imgs):
-        """
-        Args:
-            imgs (dict): dict of image info.
-
-        Returns:
-            tuple: Image name & id mapping dicts.
-
-            - id2name (dict): Mapping image id to name.
-            - name2id (dict): Mapping image name to id.
-        """
-        id2name = {}
-        name2id = {}
-        for image_id, image in imgs.items():
-            file_name = image['file_name']
-            id2name[image_id] = file_name
-            name2id[file_name] = image_id
-
-        return id2name, name2id
-
-    def _xywh2cs(self, x, y, w, h, padding=1.):
-        """This encodes bbox(x,y,w,h) into (center, scale)
-
-        Args:
-            x, y, w, h
-
-        Returns:
-            center (np.ndarray[float32](2,)): center of the bbox (x, y).
-            scale (np.ndarray[float32](2,)): scale of the bbox w & h.
-        """
-        aspect_ratio = self.ann_info['image_size'][0] / self.ann_info[
-            'image_size'][1]
-        center = np.array([x + w * 0.5, y + h * 0.5], dtype=np.float32)
-
-        if (not self.test_mode) and np.random.rand() < 0.3:
-            center += 0.4 * (np.random.rand(2) - 0.5) * [w, h]
-
-        if w > aspect_ratio * h:
-            h = w * 1.0 / aspect_ratio
-        elif w < aspect_ratio * h:
-            w = h * aspect_ratio
-
-        # pixel std is 200.0
-        scale = np.array([w / 200.0, h / 200.0], dtype=np.float32)
-        # padding to include proper amount of context
-        scale = scale * padding
-
-        return center, scale
-
     def _get_db(self):
         """Load dataset."""
         gt_db = []
@@ -237,64 +184,6 @@ class TopDownH36MDataset(TopDownBaseDataset):
 
         return name_value
 
-    def _report_metric(self, res_file, metrics, pck_thr=0.05):
-        """Keypoint evaluation.
-
-        Args:
-            res_file (str): Json file stored prediction results.
-            metrics (str | list[str]): Metric to be performed.
-                Options: 'PCK', 'PCKh', 'AUC', 'EPE'.
-            pck_thr (float): PCK threshold, default as 0.05.
-            auc_nor (float): AUC normalization factor, default as 30 pixel.
-
-        Returns:
-            List: Evaluation results for evaluation metric.
-        """
-        info_str = []
-
-        with open(res_file, 'r') as fin:
-            preds = json.load(fin)
-        assert len(preds) == len(self.db)
-
-        outputs = []
-        gts = []
-        masks = []
-        threshold_bbox = []
-
-        for pred, item in zip(preds, self.db):
-            outputs.append(np.array(pred['keypoints'])[:, :-1])
-            gts.append(np.array(item['joints_3d'])[:, :-1])
-            masks.append((np.array(item['joints_3d_visible'])[:, 0]) > 0)
-            if 'PCK' in metrics:
-                bbox = np.array(item['bbox'])
-                bbox_thr = np.max(bbox[2:])
-                threshold_bbox.append(np.array([bbox_thr, bbox_thr]))
-
-        outputs = np.array(outputs)
-        gts = np.array(gts)
-        masks = np.array(masks)
-        threshold_bbox = np.array(threshold_bbox)
-
-        if 'PCK' in metrics:
-            _, pck, _ = keypoint_pck_accuracy(outputs, gts, masks, pck_thr,
-                                              threshold_bbox)
-            info_str.append(('PCK', pck))
-
-        if 'EPE' in metrics:
-            info_str.append(('EPE', keypoint_epe(outputs, gts, masks)))
-
-        return info_str
-
-    def _sort_and_unique_bboxes(self, kpts, key='bbox_id'):
-        """sort kpts and remove the repeated ones."""
-        kpts = sorted(kpts, key=lambda x: x[key])
-        num = len(kpts)
-        for i in range(num - 1, 0, -1):
-            if kpts[i][key] == kpts[i - 1][key]:
-                del kpts[i]
-
-        return kpts
-
     @staticmethod
     def _write_keypoint_results(keypoints, res_file):
         """Write results into a json file."""
