@@ -6,14 +6,19 @@ from collections import OrderedDict, defaultdict
 
 import json_tricks as json
 import numpy as np
-from poseval import eval_helpers
-from poseval.evaluateAP import evaluateAP
-from xtcocotools.coco import COCO
+from mmcv import Config
 
 from ....core.post_processing import oks_nms, soft_oks_nms
 from ...builder import DATASETS
 from .topdown_coco_dataset import TopDownCocoDataset
 
+try:
+    from poseval import eval_helpers
+    from poseval.evaluateAP import evaluateAP
+    has_poseval = True
+except (ImportError, ModuleNotFoundError):
+    has_poseval = False
+
 
 @DATASETS.register_module()
 class TopDownPoseTrack18Dataset(TopDownCocoDataset):
@@ -51,6 +56,7 @@ class TopDownPoseTrack18Dataset(TopDownCocoDataset):
             Default: None.
         data_cfg (dict): config
         pipeline (list[dict | callable]): A sequence of data transforms.
+        dataset_info (DatasetInfo): A class containing all dataset info.
         test_mode (bool): Store True when building test or
             validation dataset. Default: False.
     """
@@ -60,61 +66,34 @@ class TopDownPoseTrack18Dataset(TopDownCocoDataset):
                  img_prefix,
                  data_cfg,
                  pipeline,
+                 dataset_info=None,
                  test_mode=False):
+
+        if dataset_info is None:
+            warnings.warn(
+                'dataset_info is missing. '
+                'Check https://github.com/open-mmlab/mmpose/pull/663 '
+                'for details.', DeprecationWarning)
+            cfg = Config.fromfile('configs/_base_/datasets/posetrack18.py')
+            dataset_info = cfg._cfg_dict['dataset_info']
+
         super(TopDownCocoDataset, self).__init__(
-            ann_file, img_prefix, data_cfg, pipeline, test_mode=test_mode)
+            ann_file,
+            img_prefix,
+            data_cfg,
+            pipeline,
+            dataset_info=dataset_info,
+            test_mode=test_mode)
 
         self.use_gt_bbox = data_cfg['use_gt_bbox']
         self.bbox_file = data_cfg['bbox_file']
         self.det_bbox_thr = data_cfg.get('det_bbox_thr', 0.0)
-        if 'image_thr' in data_cfg:
-            warnings.warn(
-                'image_thr is deprecated, '
-                'please use det_bbox_thr instead', DeprecationWarning)
-            self.det_bbox_thr = data_cfg['image_thr']
         self.use_nms = data_cfg.get('use_nms', True)
         self.soft_nms = data_cfg['soft_nms']
         self.nms_thr = data_cfg['nms_thr']
         self.oks_thr = data_cfg['oks_thr']
         self.vis_thr = data_cfg['vis_thr']
 
-        self.ann_info['flip_pairs'] = [[3, 4], [5, 6], [7, 8], [9, 10],
-                                       [11, 12], [13, 14], [15, 16]]
-
-        self.ann_info['upper_body_ids'] = (0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10)
-        self.ann_info['lower_body_ids'] = (11, 12, 13, 14, 15, 16)
-
-        self.ann_info['use_different_joint_weights'] = False
-        self.ann_info['joint_weights'] = np.array(
-            [
-                1., 1., 1., 1., 1., 1., 1., 1.2, 1.2, 1.5, 1.5, 1., 1., 1.2,
-                1.2, 1.5, 1.5
-            ],
-            dtype=np.float32).reshape((self.ann_info['num_joints'], 1))
-
-        # Adapted from COCO dataset
-        self.sigmas = np.array([
-            .26, .25, .25, .35, .35, .79, .79, .72, .72, .62, .62, 1.07, 1.07,
-            .87, .87, .89, .89
-        ]) / 10.0
-
-        self.coco = COCO(ann_file)
-
-        cats = [
-            cat['name'] for cat in self.coco.loadCats(self.coco.getCatIds())
-        ]
-        self.classes = ['__background__'] + cats
-        self.num_classes = len(self.classes)
-        self._class_to_ind = dict(zip(self.classes, range(self.num_classes)))
-        self._class_to_coco_ind = dict(zip(cats, self.coco.getCatIds()))
-        self._coco_ind_to_class_ind = dict(
-            (self._class_to_coco_ind[cls], self._class_to_ind[cls])
-            for cls in self.classes[1:])
-        self.img_ids = self.coco.getImgIds()
-        self.num_images = len(self.img_ids)
-        self.id2name, self.name2id = self._get_mapping_id_name(self.coco.imgs)
-        self.dataset_name = 'posetrack18'
-
         self.db = self._get_db()
 
         print(f'=> num_images: {self.num_images}')
@@ -152,8 +131,8 @@ class TopDownPoseTrack18Dataset(TopDownCocoDataset):
         pred_folder = osp.join(res_folder, 'preds')
         os.makedirs(pred_folder, exist_ok=True)
         gt_folder = osp.join(
-            osp.dirname(self.annotations_path),
-            osp.splitext(self.annotations_path.split('_')[-1])[0])
+            osp.dirname(self.ann_file),
+            osp.splitext(self.ann_file.split('_')[-1])[0])
 
         kpts = defaultdict(list)
 
@@ -285,6 +264,11 @@ class TopDownPoseTrack18Dataset(TopDownCocoDataset):
     def _do_python_keypoint_eval(self, gt_folder, pred_folder):
         """Keypoint evaluation using poseval."""
 
+        if not has_poseval:
+            raise ImportError('Please install poseval package for evaluation'
+                              'on PoseTrack dataset '
+                              '(see requirements/optional.txt)')
+
         argv = ['', gt_folder + '/', pred_folder + '/']
 
         print('Loading data')
