@@ -118,9 +118,9 @@ def _resize_align_multi_scale_udp(image, input_size, current_scale, min_scale):
 
     trans = get_warp_matrix(
         theta=0,
-        size_input=np.array(scale, dtype=float),
-        size_dst=np.array(size_resized, dtype=float) - 1.0,
-        size_target=np.array(scale, dtype=float))
+        size_input=np.array(scale, dtype=np.float32),
+        size_dst=np.array(size_resized, dtype=np.float32) - 1.0,
+        size_target=np.array(scale, dtype=np.float32))
     image_resized = cv2.warpAffine(
         image.copy(), trans, size_resized, flags=cv2.INTER_LINEAR)
 
@@ -160,6 +160,7 @@ class HeatmapGenerator:
         """Generate heatmaps."""
         hms = np.zeros((self.num_joints, self.output_size, self.output_size),
                        dtype=np.float32)
+
         sigma = self.sigma
         for p in joints:
             for idx, pt in enumerate(p):
@@ -284,17 +285,20 @@ class PAFGenerator:
         min_y = max(np.floor(min(src[1], dst[1]) - self.limb_width), 0)
         max_y = min(
             np.ceil(max(src[1], dst[1]) + self.limb_width),
-            self.output_size + 1)
+            self.output_size - 1)
 
         range_x = list(range(int(min_x), int(max_x + 1), 1))
         range_y = list(range(int(min_y), int(max_y + 1), 1))
-        xx, yy = np.meshgrid(range_x, range_y)
-        delta_x = xx - src[0]
-        delta_y = yy - src[1]
-        dist = np.abs(delta_x * unit_limb_vec[1] - delta_y * unit_limb_vec[0])
-        mask_local = (dist < self.limb_width)
+
         mask = np.zeros_like(count, dtype=bool)
-        mask[xx, yy] = mask_local
+        if len(range_x) > 0 and len(range_y) > 0:
+            xx, yy = np.meshgrid(range_x, range_y)
+            delta_x = xx - src[0]
+            delta_y = yy - src[1]
+            dist = np.abs(delta_x * unit_limb_vec[1] -
+                          delta_y * unit_limb_vec[0])
+            mask_local = (dist < self.limb_width)
+            mask[yy, xx] = mask_local
 
         pafs[0, mask] += unit_limb_vec[0]
         pafs[1, mask] += unit_limb_vec[1]
@@ -313,8 +317,8 @@ class PAFGenerator:
                              dtype=np.float32)
 
             for p in joints:
-                src = p[sk[0] - 1]
-                dst = p[sk[1] - 1]
+                src = p[sk[0]]
+                dst = p[sk[1]]
                 if src[2] > 0 and dst[2] > 0:
                     self._accumulate_paf_map_(pafs[2 * idx:2 * idx + 2],
                                               src[:2], dst[:2], count)
@@ -348,9 +352,9 @@ class BottomUpRandomFlip:
         assert len(mask) == len(self.output_size)
 
         if np.random.random() < self.flip_prob:
-            image = image[:, ::-1] - np.zeros_like(image)
+            image = image[:, ::-1].copy() - np.zeros_like(image)
             for i, _output_size in enumerate(self.output_size):
-                mask[i] = mask[i][:, ::-1]
+                mask[i] = mask[i][:, ::-1].copy()
                 joints[i] = joints[i][:, self.flip_index]
                 joints[i][:, :, 0] = _output_size - joints[i][:, :, 0] - 1
         results['img'], results['mask'], results[
@@ -458,8 +462,8 @@ class BottomUpRandomAffine:
                     theta=aug_rot,
                     size_input=center * 2.0,
                     size_dst=np.array(
-                        (_output_size, _output_size), dtype=float) - 1.0,
-                    size_target=np.array((scale, scale), dtype=float))
+                        (_output_size, _output_size), dtype=np.float32) - 1.0,
+                    size_target=np.array((scale, scale), dtype=np.float32))
                 mask[i] = cv2.warpAffine(
                     (mask[i] * 255).astype(np.uint8),
                     trans, (int(_output_size), int(_output_size)),
@@ -473,8 +477,9 @@ class BottomUpRandomAffine:
                 theta=aug_rot,
                 size_input=center * 2.0,
                 size_dst=np.array(
-                    (self.input_size, self.input_size), dtype=float) - 1.0,
-                size_target=np.array((scale, scale), dtype=float))
+                    (self.input_size, self.input_size), dtype=np.float32) -
+                1.0,
+                size_target=np.array((scale, scale), dtype=np.float32))
             image = cv2.warpAffine(
                 image,
                 mat_input, (int(self.input_size), int(self.input_size)),
@@ -548,7 +553,7 @@ class BottomUpGenerateHeatmapTarget:
 
 @PIPELINES.register_module()
 class BottomUpGenerateTarget:
-    """Generate multi-scale heatmap target for bottom-up.
+    """Generate multi-scale heatmap target for associate embedding.
 
     Args:
         sigma (int): Sigma of heatmap Gaussian
@@ -626,9 +631,6 @@ class BottomUpGeneratePAFTarget:
         if self.skeleton is None:
             assert results['ann_info']['skeleton'] is not None
             self.skeleton = results['ann_info']['skeleton']
-        else:
-            assert np.array(
-                self.skeleton).max() < results['ann_info']['num_joints']
 
         paf_generator = \
             self._generate(results['ann_info']['heatmap_size'],
