@@ -415,29 +415,31 @@ class MultitaskGatherTarget:
         pipeline_indices (list[int]): Pipeline index of each head.
     """
 
-    def __init__(self, pipeline_list, pipeline_indices):
+    def __init__(self,
+                 pipeline_list,
+                 pipeline_indices=None,
+                 keys=('target', 'target_weight')):
+        self.keys = keys
         self.pipelines = []
         for pipeline in pipeline_list:
             self.pipelines.append(Compose(pipeline))
-        self.pipeline_indices = pipeline_indices
+        if pipeline_indices is None:
+            self.pipeline_indices = list(range(len(pipeline_list)))
+        else:
+            self.pipeline_indices = pipeline_indices
 
     def __call__(self, results):
         # generate target and target weights using all pipelines
-        _target, _target_weight = [], []
+        pipeline_outputs = []
         for pipeline in self.pipelines:
-            results_head = pipeline(results)
-            _target.append(results_head['target'])
-            _target_weight.append(results_head['target_weight'])
+            pipeline_output = pipeline(results)
+            pipeline_outputs.append(pipeline_output.copy())
 
-        # reorganize generated target, target_weights according
-        # to self.pipelines_indices
-        target, target_weight = [], []
-        for ind in self.pipeline_indices:
-            target.append(_target[ind])
-            target_weight.append(_target_weight[ind])
-
-        results['target'] = target
-        results['target_weight'] = target_weight
+        for key in self.keys:
+            result_key = []
+            for ind in self.pipeline_indices:
+                result_key.append(pipeline_outputs[ind].get(key, None))
+            results[key] = result_key
         return results
 
 
