@@ -4,10 +4,12 @@ import warnings
 import mmcv
 import torch
 from mmcv.image import imwrite
+from mmcv.utils.misc import deprecated_api_warning
 from mmcv.visualization.image import imshow
 
-from mmpose.core.evaluation import (aggregate_results, get_group_preds,
-                                    get_multi_stage_outputs)
+from mmpose.core.evaluation import (aggregate_scale, aggregate_stage_flip,
+                                    flip_feature_maps, get_group_preds,
+                                    split_ae_outputs)
 from mmpose.core.post_processing.group import HeatmapParser
 from mmpose.core.visualization import imshow_keypoints
 from .. import builder
@@ -49,7 +51,6 @@ class AssociativeEmbedding(BasePose):
         self.backbone = builder.build_backbone(backbone)
 
         if keypoint_head is not None:
-
             if 'loss_keypoint' not in keypoint_head and loss_pose is not None:
                 warnings.warn(
                     '`loss_pose` for BottomUp is deprecated, '
@@ -99,11 +100,11 @@ class AssociativeEmbedding(BasePose):
             heatmaps height: H
             max_num_people: M
         Args:
-            img(torch.Tensor[NxCximgHximgW]): Input image.
-            targets(List(torch.Tensor[NxKxHxW])): Multi-scale target heatmaps.
-            masks(List(torch.Tensor[NxHxW])): Masks of multi-scale target
+            img (torch.Tensor[NxCximgHximgW]): Input image.
+            targets (List(torch.Tensor[NxKxHxW])): Multi-scale target heatmaps.
+            masks (List(torch.Tensor[NxHxW])): Masks of multi-scale target
                                               heatmaps
-            joints(List(torch.Tensor[NxMxKx2])): Joints of multi-scale target
+            joints (List(torch.Tensor[NxMxKx2])): Joints of multi-scale target
                                                  heatmaps for ae loss
             img_metas(dict):Information about val&test
                 By default this includes:
@@ -145,13 +146,13 @@ class AssociativeEmbedding(BasePose):
             max_num_people: M
 
         Args:
-            img(torch.Tensor[NxCximgHximgW]): Input image.
-            targets(List(torch.Tensor[NxKxHxW])): Multi-scale target heatmaps.
-            masks(List(torch.Tensor[NxHxW])): Masks of multi-scale target
+            img (torch.Tensor[NxCximgHximgW]): Input image.
+            targets (List(torch.Tensor[NxKxHxW])): Multi-scale target heatmaps.
+            masks (List(torch.Tensor[NxHxW])): Masks of multi-scale target
                                               heatmaps
-            joints(List(torch.Tensor[NxMxKx2])): Joints of multi-scale target
+            joints (List(torch.Tensor[NxMxKx2])): Joints of multi-scale target
                                                  heatmaps for ae loss
-            img_metas(dict):Information about val&test
+            img_metas (dict):Information about val&test
                 By default this includes:
                 - "image_file": image path
                 - "aug_data": input
@@ -226,8 +227,9 @@ class AssociativeEmbedding(BasePose):
 
         result = {}
 
-        aggregated_heatmaps = None
-        tags_list = []
+        scale_heatmaps_list = []
+        scale_tags_list = []
+
         for idx, s in enumerate(sorted(test_scale_factor, reverse=True)):
             image_resized = aug_data[idx].to(img.device)
 
@@ -235,45 +237,81 @@ class AssociativeEmbedding(BasePose):
             if self.with_keypoint:
                 outputs = self.keypoint_head(features)
 
+            heatmaps, tags = split_ae_outputs(
+                outputs, self.test_cfg['num_joints'],
+                self.test_cfg['with_heatmaps'], self.test_cfg['with_ae'],
+                self.test_cfg.get('select_output_index', range(len(outputs))))
+
             if self.test_cfg.get('flip_test', True):
                 # use flip test
                 features_flipped = self.backbone(
                     torch.flip(image_resized, [3]))
                 if self.with_keypoint:
                     outputs_flipped = self.keypoint_head(features_flipped)
+
+                heatmaps_flipped, tags_flipped = split_ae_outputs(
+                    outputs_flipped, self.test_cfg['num_joints'],
+                    self.test_cfg['with_heatmaps'], self.test_cfg['with_ae'],
+                    self.test_cfg.get('select_output_index',
+                                      range(len(outputs))))
+
+                heatmaps_flipped = flip_feature_maps(
+                    heatmaps_flipped, flip_index=img_metas['flip_index'])
+                if self.test_cfg['tag_per_joint']:
+                    tags_flipped = flip_feature_maps(
+                        tags_flipped, flip_index=img_metas['flip_index'])
+                else:
+                    tags_flipped = flip_feature_maps(
+                        tags_flipped, flip_index=None, flip_output=True)
+
             else:
-                outputs_flipped = None
+                heatmaps_flipped = None
+                tags_flipped = None
 
-            _, heatmaps, tags = get_multi_stage_outputs(
-                outputs,
-                outputs_flipped,
-                self.test_cfg['num_joints'],
-                self.test_cfg['with_heatmaps'],
-                self.test_cfg['with_ae'],
-                self.test_cfg['tag_per_joint'],
-                img_metas['flip_index'],
-                self.test_cfg['project2image'],
-                base_size,
-                align_corners=self.use_udp)
-
-            aggregated_heatmaps, tags_list = aggregate_results(
-                s,
-                aggregated_heatmaps,
-                tags_list,
+            aggregated_heatmaps = aggregate_stage_flip(
                 heatmaps,
-                tags,
-                test_scale_factor,
-                self.test_cfg['project2image'],
-                self.test_cfg.get('flip_test', True),
-                align_corners=self.use_udp)
+                heatmaps_flipped,
+                index=-1,
+                project2image=self.test_cfg['project2image'],
+                size_projected=base_size,
+                align_corners=self.test_cfg.get('align_corners', True),
+                aggregate_stage='average',
+                aggregate_flip='average')
 
-        # average heatmaps of different scales
-        aggregated_heatmaps = aggregated_heatmaps / float(
-            len(test_scale_factor))
-        tags = torch.cat(tags_list, dim=4)
+            aggregated_tags = aggregate_stage_flip(
+                tags,
+                tags_flipped,
+                index=-1,
+                project2image=self.test_cfg['project2image'],
+                size_projected=base_size,
+                align_corners=self.test_cfg.get('align_corners', True),
+                aggregate_stage='concat',
+                aggregate_flip='concat')
+
+            if s == 1 or len(test_scale_factor) == 1:
+                if isinstance(aggregated_tags, list):
+                    scale_tags_list.extend(aggregated_tags)
+                else:
+                    scale_tags_list.append(aggregated_tags)
+
+            if isinstance(aggregated_heatmaps, list):
+                scale_heatmaps_list.extend(aggregated_heatmaps)
+            else:
+                scale_heatmaps_list.append(aggregated_heatmaps)
+
+        aggregated_heatmaps = aggregate_scale(
+            scale_heatmaps_list,
+            align_corners=self.test_cfg.get('align_corners', True),
+            aggregate_scale='average')
+
+        aggregated_tags = aggregate_scale(
+            scale_tags_list,
+            align_corners=self.test_cfg.get('align_corners', True),
+            aggregate_scale='unsqueeze_concat')
 
         # perform grouping
-        grouped, scores = self.parser.parse(aggregated_heatmaps, tags,
+        grouped, scores = self.parser.parse(aggregated_heatmaps,
+                                            aggregated_tags,
                                             self.test_cfg['adjust'],
                                             self.test_cfg['refine'])
 
@@ -299,6 +337,8 @@ class AssociativeEmbedding(BasePose):
 
         return result
 
+    @deprecated_api_warning({'pose_limb_color': 'pose_link_color'},
+                            cls_name='AssociativeEmbedding')
     def show_result(self,
                     img,
                     result,
@@ -306,7 +346,7 @@ class AssociativeEmbedding(BasePose):
                     kpt_score_thr=0.3,
                     bbox_color=None,
                     pose_kpt_color=None,
-                    pose_limb_color=None,
+                    pose_link_color=None,
                     radius=4,
                     thickness=1,
                     font_scale=0.5,
@@ -322,12 +362,13 @@ class AssociativeEmbedding(BasePose):
             result (list[dict]): The results to draw over `img`
                 (bbox_result, pose_result).
             skeleton (list[list]): The connection of keypoints.
+                skeleton is 0-based indexing.
             kpt_score_thr (float, optional): Minimum score of keypoints
                 to be shown. Default: 0.3.
             pose_kpt_color (np.array[Nx3]`): Color of N keypoints.
                 If None, do not draw keypoints.
-            pose_limb_color (np.array[Mx3]): Color of M limbs.
-                If None, do not draw limbs.
+            pose_link_color (np.array[Mx3]): Color of M links.
+                If None, do not draw links.
             radius (int): Radius of circles.
             thickness (int): Thickness of lines.
             font_scale (float): Font scales of texts.
@@ -343,7 +384,6 @@ class AssociativeEmbedding(BasePose):
         Returns:
             Tensor: Visualized image only if not `show` or `out_file`
         """
-
         img = mmcv.imread(img)
         img = img.copy()
         img_h, img_w, _ = img.shape
@@ -353,7 +393,7 @@ class AssociativeEmbedding(BasePose):
             pose_result.append(res['keypoints'])
 
         imshow_keypoints(img, pose_result, skeleton, kpt_score_thr,
-                         pose_kpt_color, pose_limb_color, radius, thickness)
+                         pose_kpt_color, pose_link_color, radius, thickness)
 
         if show:
             imshow(img, win_name, wait_time)
