@@ -1,6 +1,8 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .ae_higher_resolution_head import AEHigherResolutionHead
+from .ae_multi_stage_head import AEMultiStageHead
 from .ae_simple_head import AESimpleHead
+from .deconv_head import DeconvHead
 from .deeppose_regression_head import DeepposeRegressionHead
 from .hmr_head import HMRMeshHead
 from .interhand_3d_head import Interhand3DHead
@@ -14,7 +16,7 @@ from .vipnas_heatmap_simple_head import ViPNASHeatmapSimpleHead
 __all__ = [
     'TopdownHeatmapSimpleHead', 'TopdownHeatmapMultiStageHead',
     'TopdownHeatmapMSMUHead', 'TopdownHeatmapBaseHead',
-    'AEHigherResolutionHead', 'AESimpleHead', 'DeepposeRegressionHead',
-    'TemporalRegressionHead', 'Interhand3DHead', 'HMRMeshHead',
-    'ViPNASHeatmapSimpleHead'
+    'AEHigherResolutionHead', 'AESimpleHead', 'AEMultiStageHead',
+    'DeepposeRegressionHead', 'TemporalRegressionHead', 'Interhand3DHead',
+    'HMRMeshHead', 'DeconvHead', 'ViPNASHeatmapSimpleHead'
 ]
